Module: Google::Apis::MerchantapiAccountsV1beta

Defined in:
lib/google/apis/merchantapi_accounts_v1beta.rb,
lib/google/apis/merchantapi_accounts_v1beta/classes.rb,
lib/google/apis/merchantapi_accounts_v1beta/service.rb,
lib/google/apis/merchantapi_accounts_v1beta/gem_version.rb,
lib/google/apis/merchantapi_accounts_v1beta/representations.rb

Overview

Merchant API

Programmatically manage your Merchant Center Accounts.

Defined Under Namespace

Classes: About, AcceptTermsOfServiceResponse, Accepted, Account, AccountAggregation, AccountIssue, AccountManagement, AccountRelationship, AccountService, AddAccountService, AddUser, Address, ApproveAccountServiceRequest, AutofeedSettings, AutomaticImageImprovements, AutomaticImprovements, AutomaticItemUpdates, AutomaticShippingImprovements, BusinessDayConfig, BusinessIdentity, BusinessInfo, CampaignsManagement, CarrierRate, CheckoutSettings, ClaimHomepageRequest, ComparisonShopping, CreateAndConfigureAccountRequest, CreateUserRequest, CustomerService, CutoffConfig, CutoffTime, Date, DeliveryTime, DeveloperRegistration, DisableProgramRequest, Distance, EmailPreferences, Empty, EnableProgramRequest, FindLfpProvidersResponse, GbpAccount, GeoTargetArea, GetAccountForGcpRegistrationResponse, Handshake, Headers, Homepage, IdentityAttribute, ImageImprovementsAccountLevelSettings, Impact, ImpactedDestination, InStock, InventoryVerification, ItemUpdatesAccountLevelSettings, LatLng, LfpLink, LfpProvider, LinkGbpAccountRequest, LinkGbpAccountResponse, LinkLfpProviderRequest, LinkLfpProviderResponse, ListAccountIssuesResponse, ListAccountRelationshipsResponse, ListAccountServicesResponse, ListAccountsResponse, ListGbpAccountsResponse, ListOmnichannelSettingsResponse, ListOnlineReturnPoliciesResponse, ListProgramsResponse, ListRegionsResponse, ListSubAccountsResponse, ListUsersResponse, LocalCutoffTime, LocalListingManagement, LocationIdSet, LoyaltyProgram, LoyaltyProgramTiers, MerchantService, MinimumOrderValueTable, OmnichannelSetting, OnDisplayToOrder, OnlineReturnPolicy, PhoneNumber, Pickup, Policy, PostalAddress, PostalCodeArea, PostalCodeRange, Price, ProductChange, ProductStatusChangeMessage, ProductsManagement, Program, ProposeAccountServiceRequest, RadiusArea, RateGroup, Region, RegisterGcpRequest, RejectAccountServiceRequest, RequestInventoryVerificationRequest, RequestInventoryVerificationResponse, Required, Requirement, RestockingFee, ReturnShippingFee, Row, SeasonalOverride, Service, SetAliasForRelationship, ShippingSettings, ShortCode, StoreCodeSetWithMov, StoreConfig, Table, TermsOfService, TermsOfServiceAgreementState, TimeZone, TransitTable, TransitTimeRow, TransitTimeValue, UnclaimHomepageRequest, UnregisterGcpRequest, UriSettings, User, Value, VerificationMailSettings, VerifySelfRequest, Warehouse, WarehouseBasedDeliveryTime, WarehouseCutoffTime, Weight

Constant Summary collapse

GEM_VERSION =

Version of the google-apis-merchantapi_accounts_v1beta gem

"0.35.0"
GENERATOR_VERSION =

Version of the code generator used to generate this client

"0.18.0"
REVISION =

Revision of the discovery document this client was generated from

"20260415"
VERSION =

Version of the Merchant API this client connects to. This is NOT the gem version.

'AccountsV1beta'
AUTH_CONTENT =

Manage your product listings and accounts for Google Shopping

'https://www.googleapis.com/auth/content'