Class: Google::Apis::MerchantapiAccountsV1beta::AcceptTermsOfServiceResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/merchantapi_accounts_v1beta/classes.rb,
lib/google/apis/merchantapi_accounts_v1beta/representations.rb,
lib/google/apis/merchantapi_accounts_v1beta/representations.rb

Overview

Response message for the AcceptTermsOfService method.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ AcceptTermsOfServiceResponse

Returns a new instance of AcceptTermsOfServiceResponse.



74
75
76
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 74

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#terms_of_service_agreement_stateGoogle::Apis::MerchantapiAccountsV1beta::TermsOfServiceAgreementState

This resource represents the agreement state for a given account and terms of service kind. The state is as follows: * If the business has accepted a terms of service, accepted will be populated, otherwise it will be empty * If the business must sign a terms of service, required will be populated, otherwise it will be empty. Note that both required and accepted can be present. In this case the accepted terms of services will have an expiration date set in the valid_until field. The required terms of services need to be accepted before valid_until in order for the account to continue having a valid agreement. When accepting new terms of services we expect third-party providers to display the text associated with the given terms of service agreement (the url to the file containing the text is added in the Required message below as tos_file_uri). The actual acceptance of the terms of service is done by calling accept on the TermsOfService resource. valid_until field. Corresponds to the JSON property termsOfServiceAgreementState



72
73
74
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 72

def terms_of_service_agreement_state
  @terms_of_service_agreement_state
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



79
80
81
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 79

def update!(**args)
  @terms_of_service_agreement_state = args[:terms_of_service_agreement_state] if args.key?(:terms_of_service_agreement_state)
end