Class: Google::Apis::MerchantapiAccountsV1beta::AccountIssue

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/merchantapi_accounts_v1beta/classes.rb,
lib/google/apis/merchantapi_accounts_v1beta/representations.rb,
lib/google/apis/merchantapi_accounts_v1beta/representations.rb

Overview

Issues with your Merchant Center account that can impact all your products. For more information, see Account-level issues in Merchant Center.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ AccountIssue

Returns a new instance of AccountIssue.



248
249
250
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 248

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#detailString

Further localized details about the issue. Corresponds to the JSON property detail

Returns:

  • (String)


218
219
220
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 218

def detail
  @detail
end

#documentation_uriString

Link to Merchant Center Help Center providing further information about the issue and how to fix it. Corresponds to the JSON property documentationUri

Returns:

  • (String)


224
225
226
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 224

def documentation_uri
  @documentation_uri
end

#impacted_destinationsArray<Google::Apis::MerchantapiAccountsV1beta::ImpactedDestination>

The impact this issue has on various destinations. Corresponds to the JSON property impactedDestinations



229
230
231
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 229

def impacted_destinations
  @impacted_destinations
end

#nameString

Identifier. The resource name of the account issue. Format: accounts/account /issues/id`. For example,accounts/123456/issues/misrepresentation-of-self- or-products-unacceptable-business-practice-policy. Corresponds to the JSON propertyname`

Returns:

  • (String)


236
237
238
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 236

def name
  @name
end

#severityString

The overall severity of the issue. Corresponds to the JSON property severity

Returns:

  • (String)


241
242
243
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 241

def severity
  @severity
end

#titleString

The localized title of the issue. Corresponds to the JSON property title

Returns:

  • (String)


246
247
248
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 246

def title
  @title
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



253
254
255
256
257
258
259
260
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 253

def update!(**args)
  @detail = args[:detail] if args.key?(:detail)
  @documentation_uri = args[:documentation_uri] if args.key?(:documentation_uri)
  @impacted_destinations = args[:impacted_destinations] if args.key?(:impacted_destinations)
  @name = args[:name] if args.key?(:name)
  @severity = args[:severity] if args.key?(:severity)
  @title = args[:title] if args.key?(:title)
end