Class: Google::Apis::MerchantapiAccountsV1beta::AddAccountService

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/merchantapi_accounts_v1beta/classes.rb,
lib/google/apis/merchantapi_accounts_v1beta/representations.rb,
lib/google/apis/merchantapi_accounts_v1beta/representations.rb

Overview

Additional instructions to add account services during creation of the account.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ AddAccountService

Returns a new instance of AddAccountService.



494
495
496
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 494

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#account_aggregationGoogle::Apis::MerchantapiAccountsV1beta::AccountAggregation

AccountAggregation payload. Corresponds to the JSON property accountAggregation



451
452
453
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 451

def 
  @account_aggregation
end

#account_managementGoogle::Apis::MerchantapiAccountsV1beta::AccountManagement

AccountManagement payload. Corresponds to the JSON property accountManagement



456
457
458
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 456

def 
  @account_management
end

#campaigns_managementGoogle::Apis::MerchantapiAccountsV1beta::CampaignsManagement

CampaignManagement payload. Corresponds to the JSON property campaignsManagement



461
462
463
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 461

def campaigns_management
  @campaigns_management
end

#comparison_shoppingGoogle::Apis::MerchantapiAccountsV1beta::ComparisonShopping

ComparisonShopping payload. Corresponds to the JSON property comparisonShopping



466
467
468
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 466

def comparison_shopping
  @comparison_shopping
end

#external_account_idString

Immutable. An optional, immutable identifier that Google uses to refer to this account when communicating with the provider. This should be the unique account ID within the provider's system (for example, your shop ID in Shopify). If you have multiple accounts with the same provider - for instance, different accounts for various regions — the external_account_id differentiates between them, ensuring accurate linking and integration between Google and the provider. The external account ID must be specified for the campaigns management service type. The external account ID must not be specified for the account aggregation service type. The external account ID is optional / may be specified for all other service types. Corresponds to the JSON property externalAccountId

Returns:

  • (String)


480
481
482
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 480

def 
  @external_account_id
end

#products_managementGoogle::Apis::MerchantapiAccountsV1beta::ProductsManagement

ProductsManagement payload. Corresponds to the JSON property productsManagement



485
486
487
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 485

def products_management
  @products_management
end

#providerString

Required. The provider of the service. Either the reference to an account such as providers/123 or a well-known service provider (one of providers/ GOOGLE_ADS or providers/GOOGLE_BUSINESS_PROFILE). Corresponds to the JSON property provider

Returns:

  • (String)


492
493
494
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 492

def provider
  @provider
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



499
500
501
502
503
504
505
506
507
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 499

def update!(**args)
  @account_aggregation = args[:account_aggregation] if args.key?(:account_aggregation)
  @account_management = args[:account_management] if args.key?(:account_management)
  @campaigns_management = args[:campaigns_management] if args.key?(:campaigns_management)
  @comparison_shopping = args[:comparison_shopping] if args.key?(:comparison_shopping)
  @external_account_id = args[:external_account_id] if args.key?(:external_account_id)
  @products_management = args[:products_management] if args.key?(:products_management)
  @provider = args[:provider] if args.key?(:provider)
end