Class: Google::Apis::MerchantapiAccountsV1beta::AddUser

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/merchantapi_accounts_v1beta/classes.rb,
lib/google/apis/merchantapi_accounts_v1beta/representations.rb,
lib/google/apis/merchantapi_accounts_v1beta/representations.rb

Overview

Instruction for adding a user to the account during creation.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ AddUser

Returns a new instance of AddUser.



532
533
534
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 532

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#userGoogle::Apis::MerchantapiAccountsV1beta::User

The User resource represents a user associated with a Merchant Center account. It is used to manage user permissions and access rights within the account. For more information, see Frequently asked questions about people and access levels. Corresponds to the JSON property user



520
521
522
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 520

def user
  @user
end

#user_idString

Required. The email address of the user (for example, john.doe@gmail.com). Corresponds to the JSON property userId

Returns:

  • (String)


525
526
527
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 525

def user_id
  @user_id
end

#verification_mail_settingsGoogle::Apis::MerchantapiAccountsV1beta::VerificationMailSettings

Settings related to the verification email that is sent after adding a user. Corresponds to the JSON property verificationMailSettings



530
531
532
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 530

def verification_mail_settings
  @verification_mail_settings
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



537
538
539
540
541
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 537

def update!(**args)
  @user = args[:user] if args.key?(:user)
  @user_id = args[:user_id] if args.key?(:user_id)
  @verification_mail_settings = args[:verification_mail_settings] if args.key?(:verification_mail_settings)
end