Class: Google::Apis::MerchantapiAccountsV1beta::AutomaticImprovements

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/merchantapi_accounts_v1beta/classes.rb,
lib/google/apis/merchantapi_accounts_v1beta/representations.rb,
lib/google/apis/merchantapi_accounts_v1beta/representations.rb

Overview

Collection of information related to the automatic improvements of an account.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ AutomaticImprovements

Returns a new instance of AutomaticImprovements.



722
723
724
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 722

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#image_improvementsGoogle::Apis::MerchantapiAccountsV1beta::AutomaticImageImprovements

This improvement will attempt to automatically correct submitted images if they don't meet the image requirements, for example, removing overlays. If successful, the image will be replaced and approved. This improvement is only applied to images of disapproved offers. For more information see: Automatic image improvements Corresponds to the JSON property imageImprovements



692
693
694
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 692

def image_improvements
  @image_improvements
end

#item_updatesGoogle::Apis::MerchantapiAccountsV1beta::AutomaticItemUpdates

Turning on item updates allows Google to automatically update items for you. When item updates are on, Google uses the structured data markup on the website and advanced data extractors to update the price and availability of the items. When the item updates are off, items with mismatched data aren't shown. Corresponds to the JSON property itemUpdates



701
702
703
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 701

def item_updates
  @item_updates
end

#nameString

Identifier. The resource name of the automatic improvements. Format: accounts/ account/automaticImprovements. Corresponds to the JSON property name

Returns:

  • (String)


707
708
709
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 707

def name
  @name
end

#shipping_improvementsGoogle::Apis::MerchantapiAccountsV1beta::AutomaticShippingImprovements

Not available for advanced accounts. By turning on automatic shipping improvements, you are allowing Google to improve the accuracy of your delivery times shown to shoppers using Google. More accurate delivery times, especially when faster, typically lead to better conversion rates. Google will improve your estimated delivery times based on various factors: * Delivery address of an order * Current handling time and shipping time settings * Estimated weekdays or business days * Parcel tracking data Corresponds to the JSON property shippingImprovements



720
721
722
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 720

def shipping_improvements
  @shipping_improvements
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



727
728
729
730
731
732
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 727

def update!(**args)
  @image_improvements = args[:image_improvements] if args.key?(:image_improvements)
  @item_updates = args[:item_updates] if args.key?(:item_updates)
  @name = args[:name] if args.key?(:name)
  @shipping_improvements = args[:shipping_improvements] if args.key?(:shipping_improvements)
end