Class: Google::Apis::MerchantapiAccountsV1beta::BusinessIdentity

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/merchantapi_accounts_v1beta/classes.rb,
lib/google/apis/merchantapi_accounts_v1beta/representations.rb,
lib/google/apis/merchantapi_accounts_v1beta/representations.rb

Overview

Collection of information related to the identity of a business.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ BusinessIdentity

Returns a new instance of BusinessIdentity.



880
881
882
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 880

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#black_ownedGoogle::Apis::MerchantapiAccountsV1beta::IdentityAttribute

All information related to an identity attribute. Corresponds to the JSON property blackOwned



847
848
849
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 847

def black_owned
  @black_owned
end

#latino_ownedGoogle::Apis::MerchantapiAccountsV1beta::IdentityAttribute

All information related to an identity attribute. Corresponds to the JSON property latinoOwned



852
853
854
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 852

def latino_owned
  @latino_owned
end

#nameString

Identifier. The resource name of the business identity. Format: accounts/ account/businessIdentity Corresponds to the JSON property name

Returns:

  • (String)


858
859
860
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 858

def name
  @name
end

Required. Whether the identity attributes may be used for promotions. Corresponds to the JSON property promotionsConsent

Returns:

  • (String)


863
864
865
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 863

def promotions_consent
  @promotions_consent
end

#small_businessGoogle::Apis::MerchantapiAccountsV1beta::IdentityAttribute

All information related to an identity attribute. Corresponds to the JSON property smallBusiness



868
869
870
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 868

def small_business
  @small_business
end

#veteran_ownedGoogle::Apis::MerchantapiAccountsV1beta::IdentityAttribute

All information related to an identity attribute. Corresponds to the JSON property veteranOwned



873
874
875
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 873

def veteran_owned
  @veteran_owned
end

#women_ownedGoogle::Apis::MerchantapiAccountsV1beta::IdentityAttribute

All information related to an identity attribute. Corresponds to the JSON property womenOwned



878
879
880
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 878

def women_owned
  @women_owned
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



885
886
887
888
889
890
891
892
893
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 885

def update!(**args)
  @black_owned = args[:black_owned] if args.key?(:black_owned)
  @latino_owned = args[:latino_owned] if args.key?(:latino_owned)
  @name = args[:name] if args.key?(:name)
  @promotions_consent = args[:promotions_consent] if args.key?(:promotions_consent)
  @small_business = args[:small_business] if args.key?(:small_business)
  @veteran_owned = args[:veteran_owned] if args.key?(:veteran_owned)
  @women_owned = args[:women_owned] if args.key?(:women_owned)
end