Class: Google::Apis::MerchantapiAccountsV1beta::CheckoutSettings

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/merchantapi_accounts_v1beta/classes.rb,
lib/google/apis/merchantapi_accounts_v1beta/representations.rb,
lib/google/apis/merchantapi_accounts_v1beta/representations.rb

Overview

CheckoutSettings for a specific merchant.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ CheckoutSettings

Returns a new instance of CheckoutSettings.



1100
1101
1102
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 1100

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#effective_enrollment_stateString

Output only. The effective value of enrollment_state for a given merchant ID. If account level settings are present then this value will be a copy of the account level settings. Otherwise, it will have the value of the parent account (for only marketplace sellers). Corresponds to the JSON property effectiveEnrollmentState

Returns:

  • (String)


1051
1052
1053
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 1051

def effective_enrollment_state
  @effective_enrollment_state
end

#effective_review_stateString

Output only. The effective value of review_state for a given merchant ID. If account level settings are present then this value will be a copy of the account level settings. Otherwise, it will have the value of the parent account (for only marketplace sellers). Corresponds to the JSON property effectiveReviewState

Returns:

  • (String)


1059
1060
1061
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 1059

def effective_review_state
  @effective_review_state
end

#effective_uri_settingsGoogle::Apis::MerchantapiAccountsV1beta::UriSettings

URL settings for cart or checkout URL. Corresponds to the JSON property effectiveUriSettings



1064
1065
1066
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 1064

def effective_uri_settings
  @effective_uri_settings
end

#eligible_destinationsArray<String>

Optional. Required for the create operation. The destinations (also known as Marketing methods) to which the checkout program applies. Valid destination values are SHOPPING_ADS and FREE_LISTINGS. Corresponds to the JSON property eligibleDestinations

Returns:

  • (Array<String>)


1072
1073
1074
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 1072

def eligible_destinations
  @eligible_destinations
end

#enrollment_stateString

Output only. Reflects the merchant enrollment state in Checkout program. Corresponds to the JSON property enrollmentState

Returns:

  • (String)


1077
1078
1079
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 1077

def enrollment_state
  @enrollment_state
end

#nameString

Identifier. The resource name of the program configuration settings. Format: accounts/account/programs/program/checkoutSettings Corresponds to the JSON property name

Returns:

  • (String)


1083
1084
1085
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 1083

def name
  @name
end

#review_stateString

Output only. Reflects the merchant review state in Checkout program. This is set based on the data quality reviews of the URL provided by the merchant. A merchant with enrollment state as ENROLLED can be in the following review states: IN_REVIEW, APPROVED or DISAPPROVED. A merchant must be in an enrollment_state of ENROLLED before a review can begin for the merchant.For more details, check the help center doc. Corresponds to the JSON property reviewState

Returns:

  • (String)


1093
1094
1095
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 1093

def review_state
  @review_state
end

#uri_settingsGoogle::Apis::MerchantapiAccountsV1beta::UriSettings

URL settings for cart or checkout URL. Corresponds to the JSON property uriSettings



1098
1099
1100
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 1098

def uri_settings
  @uri_settings
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1105
1106
1107
1108
1109
1110
1111
1112
1113
1114
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 1105

def update!(**args)
  @effective_enrollment_state = args[:effective_enrollment_state] if args.key?(:effective_enrollment_state)
  @effective_review_state = args[:effective_review_state] if args.key?(:effective_review_state)
  @effective_uri_settings = args[:effective_uri_settings] if args.key?(:effective_uri_settings)
  @eligible_destinations = args[:eligible_destinations] if args.key?(:eligible_destinations)
  @enrollment_state = args[:enrollment_state] if args.key?(:enrollment_state)
  @name = args[:name] if args.key?(:name)
  @review_state = args[:review_state] if args.key?(:review_state)
  @uri_settings = args[:uri_settings] if args.key?(:uri_settings)
end