Class: Google::Apis::MerchantapiAccountsV1beta::CustomerService
- Inherits:
-
Object
- Object
- Google::Apis::MerchantapiAccountsV1beta::CustomerService
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/merchantapi_accounts_v1beta/classes.rb,
lib/google/apis/merchantapi_accounts_v1beta/representations.rb,
lib/google/apis/merchantapi_accounts_v1beta/representations.rb
Overview
Customer service information.
Instance Attribute Summary collapse
-
#email ⇒ String
Optional.
-
#phone ⇒ Google::Apis::MerchantapiAccountsV1beta::PhoneNumber
An object representing a phone number, suitable as an API wire format.
-
#uri ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ CustomerService
constructor
A new instance of CustomerService.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ CustomerService
Returns a new instance of CustomerService.
1278 1279 1280 |
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 1278 def initialize(**args) update!(**args) end |
Instance Attribute Details
#email ⇒ String
Optional. The email address where customer service may be reached.
Corresponds to the JSON property email
1254 1255 1256 |
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 1254 def email @email end |
#phone ⇒ Google::Apis::MerchantapiAccountsV1beta::PhoneNumber
An object representing a phone number, suitable as an API wire format. This
representation: - should not be used for locale-specific formatting of a phone
number, such as "+1 (650) 253-0000 ext. 123" - is not designed for efficient
storage - may not be suitable for dialing - specialized libraries (see
references) should be used to parse the number for that purpose To do
something meaningful with this number, such as format it for various use-cases,
convert it to an i18n.phonenumbers.PhoneNumber object first. For instance,
in Java this would be: com.google.type.PhoneNumber wireProto = com.google.type.
PhoneNumber.newBuilder().build(); com.google.i18n.phonenumbers.Phonenumber.
PhoneNumber phoneNumber = PhoneNumberUtil.getInstance().parse(wireProto.
getE164Number(), "ZZ"); if (!wireProto.getExtension().isEmpty()) phoneNumber.
setExtension(wireProto.getExtension()); Reference(s): - https://github.com/
google/libphonenumber
Corresponds to the JSON property phone
1271 1272 1273 |
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 1271 def phone @phone end |
#uri ⇒ String
Optional. The URI where customer service may be found.
Corresponds to the JSON property uri
1276 1277 1278 |
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 1276 def uri @uri end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1283 1284 1285 1286 1287 |
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 1283 def update!(**args) @email = args[:email] if args.key?(:email) @phone = args[:phone] if args.key?(:phone) @uri = args[:uri] if args.key?(:uri) end |