Class: Google::Apis::MerchantapiAccountsV1beta::CutoffConfig
- Inherits:
-
Object
- Object
- Google::Apis::MerchantapiAccountsV1beta::CutoffConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/merchantapi_accounts_v1beta/classes.rb,
lib/google/apis/merchantapi_accounts_v1beta/representations.rb,
lib/google/apis/merchantapi_accounts_v1beta/representations.rb
Overview
Configs related to local delivery ends for the day.
Instance Attribute Summary collapse
-
#local_cutoff_time ⇒ Google::Apis::MerchantapiAccountsV1beta::LocalCutoffTime
Time that local delivery ends for the day.
-
#no_delivery_post_cutoff ⇒ Boolean
(also: #no_delivery_post_cutoff?)
Businesses can opt-out of showing n+1 day local delivery when they have a shipping service configured to n day local delivery.
-
#store_close_offset_hours ⇒ Fixnum
Only valid with local delivery fulfillment.
Instance Method Summary collapse
-
#initialize(**args) ⇒ CutoffConfig
constructor
A new instance of CutoffConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ CutoffConfig
Returns a new instance of CutoffConfig.
1324 1325 1326 |
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 1324 def initialize(**args) update!(**args) end |
Instance Attribute Details
#local_cutoff_time ⇒ Google::Apis::MerchantapiAccountsV1beta::LocalCutoffTime
Time that local delivery ends for the day.
Corresponds to the JSON property localCutoffTime
1303 1304 1305 |
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 1303 def local_cutoff_time @local_cutoff_time end |
#no_delivery_post_cutoff ⇒ Boolean Also known as: no_delivery_post_cutoff?
Businesses can opt-out of showing n+1 day local delivery when they have a
shipping service configured to n day local delivery. For example, if the
shipping service defines same-day delivery, and it's past the cut-off, setting
this field to true results in the calculated shipping service rate returning
NO_DELIVERY_POST_CUTOFF. In the same example, setting this field to false
results in the calculated shipping time being one day. This is only for local
delivery.
Corresponds to the JSON property noDeliveryPostCutoff
1314 1315 1316 |
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 1314 def no_delivery_post_cutoff @no_delivery_post_cutoff end |
#store_close_offset_hours ⇒ Fixnum
Only valid with local delivery fulfillment. Represents cutoff time as the
number of hours before store closing. Mutually exclusive with
local_cutoff_time.
Corresponds to the JSON property storeCloseOffsetHours
1322 1323 1324 |
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 1322 def store_close_offset_hours @store_close_offset_hours end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1329 1330 1331 1332 1333 |
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 1329 def update!(**args) @local_cutoff_time = args[:local_cutoff_time] if args.key?(:local_cutoff_time) @no_delivery_post_cutoff = args[:no_delivery_post_cutoff] if args.key?(:no_delivery_post_cutoff) @store_close_offset_hours = args[:store_close_offset_hours] if args.key?(:store_close_offset_hours) end |