Class: Google::Apis::MerchantapiAccountsV1beta::CutoffTime

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/merchantapi_accounts_v1beta/classes.rb,
lib/google/apis/merchantapi_accounts_v1beta/representations.rb,
lib/google/apis/merchantapi_accounts_v1beta/representations.rb

Overview

Business days cutoff time definition.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ CutoffTime

Returns a new instance of CutoffTime.



1358
1359
1360
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 1358

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#hourFixnum

Required. Hour of the cutoff time until which an order has to be placed to be processed in the same day. Corresponds to the JSON property hour

Returns:

  • (Fixnum)


1344
1345
1346
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 1344

def hour
  @hour
end

#minuteFixnum

Required. Minute of the cutoff time until which an order has to be placed to be processed in the same day. Corresponds to the JSON property minute

Returns:

  • (Fixnum)


1350
1351
1352
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 1350

def minute
  @minute
end

#time_zoneString

Required. Timezone identifier For example "Europe/Zurich". Corresponds to the JSON property timeZone

Returns:

  • (String)


1356
1357
1358
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 1356

def time_zone
  @time_zone
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1363
1364
1365
1366
1367
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 1363

def update!(**args)
  @hour = args[:hour] if args.key?(:hour)
  @minute = args[:minute] if args.key?(:minute)
  @time_zone = args[:time_zone] if args.key?(:time_zone)
end