Class: Google::Apis::MerchantapiAccountsV1beta::DeliveryTime

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/merchantapi_accounts_v1beta/classes.rb,
lib/google/apis/merchantapi_accounts_v1beta/representations.rb,
lib/google/apis/merchantapi_accounts_v1beta/representations.rb

Overview

Time spent in various aspects from order to the delivery of the product.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ DeliveryTime

Returns a new instance of DeliveryTime.



1473
1474
1475
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 1473

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#cutoff_timeGoogle::Apis::MerchantapiAccountsV1beta::CutoffTime

Business days cutoff time definition. Corresponds to the JSON property cutoffTime



1418
1419
1420
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 1418

def cutoff_time
  @cutoff_time
end

#handling_business_day_configGoogle::Apis::MerchantapiAccountsV1beta::BusinessDayConfig

Business days of the warehouse. Corresponds to the JSON property handlingBusinessDayConfig



1423
1424
1425
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 1423

def handling_business_day_config
  @handling_business_day_config
end

#max_handling_daysFixnum

Maximum number of business days spent before an order is shipped. 0 means same day shipped, 1 means next day shipped. Must be greater than or equal to min_handling_days. 'min_handling_days' and 'max_handling_days' should be either set or not set at the same time. Corresponds to the JSON property maxHandlingDays

Returns:

  • (Fixnum)


1431
1432
1433
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 1431

def max_handling_days
  @max_handling_days
end

#max_transit_daysFixnum

Maximum number of business days that is spent in transit. 0 means same day delivery, 1 means next day delivery. Must be greater than or equal to min_transit_days. Corresponds to the JSON property maxTransitDays

Returns:

  • (Fixnum)


1438
1439
1440
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 1438

def max_transit_days
  @max_transit_days
end

#min_handling_daysFixnum

Minimum number of business days spent before an order is shipped. 0 means same day shipped, 1 means next day shipped. 'min_handling_days' and ' max_handling_days' should be either set or not set at the same time. Corresponds to the JSON property minHandlingDays

Returns:

  • (Fixnum)


1445
1446
1447
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 1445

def min_handling_days
  @min_handling_days
end

#min_transit_daysFixnum

Minimum number of business days that is spent in transit. 0 means same day delivery, 1 means next day delivery. Either min_transit_days, max_transit_days or transit_time_table must be set, but not both. Corresponds to the JSON property minTransitDays

Returns:

  • (Fixnum)


1452
1453
1454
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 1452

def min_transit_days
  @min_transit_days
end

#transit_business_day_configGoogle::Apis::MerchantapiAccountsV1beta::BusinessDayConfig

Business days of the warehouse. Corresponds to the JSON property transitBusinessDayConfig



1457
1458
1459
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 1457

def transit_business_day_config
  @transit_business_day_config
end

#transit_time_tableGoogle::Apis::MerchantapiAccountsV1beta::TransitTable

Transit time table, number of business days spent in transit based on row and column dimensions. Either min_transit_days, max_transit_days or transit_time_table can be set, but not both. Corresponds to the JSON property transitTimeTable



1464
1465
1466
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 1464

def transit_time_table
  @transit_time_table
end

#warehouse_based_delivery_timesArray<Google::Apis::MerchantapiAccountsV1beta::WarehouseBasedDeliveryTime>

Optional. Indicates that the delivery time should be calculated per warehouse ( shipping origin location) based on the settings of the selected carrier. When set, no other transit time related field in delivery time should be set. Corresponds to the JSON property warehouseBasedDeliveryTimes



1471
1472
1473
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 1471

def warehouse_based_delivery_times
  @warehouse_based_delivery_times
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1478
1479
1480
1481
1482
1483
1484
1485
1486
1487
1488
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 1478

def update!(**args)
  @cutoff_time = args[:cutoff_time] if args.key?(:cutoff_time)
  @handling_business_day_config = args[:handling_business_day_config] if args.key?(:handling_business_day_config)
  @max_handling_days = args[:max_handling_days] if args.key?(:max_handling_days)
  @max_transit_days = args[:max_transit_days] if args.key?(:max_transit_days)
  @min_handling_days = args[:min_handling_days] if args.key?(:min_handling_days)
  @min_transit_days = args[:min_transit_days] if args.key?(:min_transit_days)
  @transit_business_day_config = args[:transit_business_day_config] if args.key?(:transit_business_day_config)
  @transit_time_table = args[:transit_time_table] if args.key?(:transit_time_table)
  @warehouse_based_delivery_times = args[:warehouse_based_delivery_times] if args.key?(:warehouse_based_delivery_times)
end