Class: Google::Apis::MerchantapiAccountsV1beta::EmailPreferences

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/merchantapi_accounts_v1beta/classes.rb,
lib/google/apis/merchantapi_accounts_v1beta/representations.rb,
lib/google/apis/merchantapi_accounts_v1beta/representations.rb

Overview

The categories of notifications the user opted into / opted out of. The email preferences do not include mandatory announcements as users can't opt out of them.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ EmailPreferences

Returns a new instance of EmailPreferences.



1575
1576
1577
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 1575

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#nameString

Identifier. The name of the EmailPreferences. The endpoint is only supported for the authenticated user. Corresponds to the JSON property name

Returns:

  • (String)


1568
1569
1570
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 1568

def name
  @name
end

#news_and_tipsString

Optional. Updates on new features, tips and best practices. Corresponds to the JSON property newsAndTips

Returns:

  • (String)


1573
1574
1575
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 1573

def news_and_tips
  @news_and_tips
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1580
1581
1582
1583
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 1580

def update!(**args)
  @name = args[:name] if args.key?(:name)
  @news_and_tips = args[:news_and_tips] if args.key?(:news_and_tips)
end