Class: Google::Apis::MerchantapiAccountsV1beta::FindLfpProvidersResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/merchantapi_accounts_v1beta/classes.rb,
lib/google/apis/merchantapi_accounts_v1beta/representations.rb,
lib/google/apis/merchantapi_accounts_v1beta/representations.rb

Overview

Response message for the FindLfpProviders method.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ FindLfpProvidersResponse

Returns a new instance of FindLfpProvidersResponse.



1624
1625
1626
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 1624

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#lfp_providersArray<Google::Apis::MerchantapiAccountsV1beta::LfpProvider>

The LFP providers from the specified merchant in the specified country. Corresponds to the JSON property lfpProviders



1616
1617
1618
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 1616

def lfp_providers
  @lfp_providers
end

#next_page_tokenString

A token, which can be sent as page_token to retrieve the next page. If this field is omitted, there are no subsequent pages. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


1622
1623
1624
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 1622

def next_page_token
  @next_page_token
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1629
1630
1631
1632
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 1629

def update!(**args)
  @lfp_providers = args[:lfp_providers] if args.key?(:lfp_providers)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
end