Class: Google::Apis::MerchantapiAccountsV1beta::GetAccountForGcpRegistrationResponse
- Inherits:
-
Object
- Object
- Google::Apis::MerchantapiAccountsV1beta::GetAccountForGcpRegistrationResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/merchantapi_accounts_v1beta/classes.rb,
lib/google/apis/merchantapi_accounts_v1beta/representations.rb,
lib/google/apis/merchantapi_accounts_v1beta/representations.rb
Overview
Response message for the GetAccountForGcpRegistration method.
Instance Attribute Summary collapse
-
#name ⇒ String
The name of the merchant account id that the GCP is registered with.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GetAccountForGcpRegistrationResponse
constructor
A new instance of GetAccountForGcpRegistrationResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GetAccountForGcpRegistrationResponse
Returns a new instance of GetAccountForGcpRegistrationResponse.
1710 1711 1712 |
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 1710 def initialize(**args) update!(**args) end |
Instance Attribute Details
#name ⇒ String
The name of the merchant account id that the GCP is registered with.
Corresponds to the JSON property name
1708 1709 1710 |
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 1708 def name @name end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1715 1716 1717 |
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 1715 def update!(**args) @name = args[:name] if args.key?(:name) end |