Class: Google::Apis::MerchantapiAccountsV1beta::Impact
- Inherits:
-
Object
- Object
- Google::Apis::MerchantapiAccountsV1beta::Impact
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/merchantapi_accounts_v1beta/classes.rb,
lib/google/apis/merchantapi_accounts_v1beta/representations.rb,
lib/google/apis/merchantapi_accounts_v1beta/representations.rb
Overview
The impact of the issue on a region.
Instance Attribute Summary collapse
-
#region_code ⇒ String
The CLDR region code where this issue applies.
-
#severity ⇒ String
The severity of the issue on the destination and region.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Impact
constructor
A new instance of Impact.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Impact
Returns a new instance of Impact.
1902 1903 1904 |
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 1902 def initialize(**args) update!(**args) end |
Instance Attribute Details
#region_code ⇒ String
The CLDR region code where this issue applies.
Corresponds to the JSON property regionCode
1895 1896 1897 |
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 1895 def region_code @region_code end |
#severity ⇒ String
The severity of the issue on the destination and region.
Corresponds to the JSON property severity
1900 1901 1902 |
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 1900 def severity @severity end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1907 1908 1909 1910 |
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 1907 def update!(**args) @region_code = args[:region_code] if args.key?(:region_code) @severity = args[:severity] if args.key?(:severity) end |