Class: Google::Apis::MerchantapiAccountsV1beta::ItemUpdatesAccountLevelSettings

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/merchantapi_accounts_v1beta/classes.rb,
lib/google/apis/merchantapi_accounts_v1beta/representations.rb,
lib/google/apis/merchantapi_accounts_v1beta/representations.rb

Overview

Settings for the Automatic Item Updates.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ItemUpdatesAccountLevelSettings

Returns a new instance of ItemUpdatesAccountLevelSettings.



2050
2051
2052
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 2050

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#allow_availability_updatesBoolean Also known as: allow_availability_updates?

If availability updates are enabled, any previous availability values get overwritten if Google finds an out-of-stock annotation on the offer's page. If additionally allow_strict_availability_updates field is set to true, values get overwritten if Google finds an in-stock annotation on the offer’s page. Corresponds to the JSON property allowAvailabilityUpdates

Returns:

  • (Boolean)


2022
2023
2024
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 2022

def allow_availability_updates
  @allow_availability_updates
end

#allow_condition_updatesBoolean Also known as: allow_condition_updates?

If condition updates are enabled, Google always updates item condition with the condition detected from the details of your product. Corresponds to the JSON property allowConditionUpdates

Returns:

  • (Boolean)


2029
2030
2031
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 2029

def allow_condition_updates
  @allow_condition_updates
end

#allow_price_updatesBoolean Also known as: allow_price_updates?

If price updates are enabled, Google always updates the active price with the crawled information. Corresponds to the JSON property allowPriceUpdates

Returns:

  • (Boolean)


2036
2037
2038
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 2036

def allow_price_updates
  @allow_price_updates
end

#allow_strict_availability_updatesBoolean Also known as: allow_strict_availability_updates?

If allow_availability_updates is enabled, items are automatically updated in all your Shopping target countries. By default, availability updates will only be applied to items that are 'out of stock' on your website but 'in stock' on Shopping. Set this to true to also update items that are 'in stock' on your website, but 'out of stock' on Google Shopping. In order for this field to have an effect, you must also set allow_availability_updates. Corresponds to the JSON property allowStrictAvailabilityUpdates

Returns:

  • (Boolean)


2047
2048
2049
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 2047

def allow_strict_availability_updates
  @allow_strict_availability_updates
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2055
2056
2057
2058
2059
2060
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 2055

def update!(**args)
  @allow_availability_updates = args[:allow_availability_updates] if args.key?(:allow_availability_updates)
  @allow_condition_updates = args[:allow_condition_updates] if args.key?(:allow_condition_updates)
  @allow_price_updates = args[:allow_price_updates] if args.key?(:allow_price_updates)
  @allow_strict_availability_updates = args[:allow_strict_availability_updates] if args.key?(:allow_strict_availability_updates)
end