Class: Google::Apis::MerchantapiAccountsV1beta::LinkLfpProviderResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/merchantapi_accounts_v1beta/classes.rb,
lib/google/apis/merchantapi_accounts_v1beta/representations.rb,
lib/google/apis/merchantapi_accounts_v1beta/representations.rb

Overview

Response message for the LinkLfpProvider method.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ LinkLfpProviderResponse

Returns a new instance of LinkLfpProviderResponse.



2222
2223
2224
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 2222

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#responseGoogle::Apis::MerchantapiAccountsV1beta::Empty

A generic empty message that you can re-use to avoid defining duplicated empty messages in your APIs. A typical example is to use it as the request or the response type of an API method. For instance: service Foo rpc Bar(google. protobuf.Empty) returns (google.protobuf.Empty); Corresponds to the JSON property response



2220
2221
2222
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 2220

def response
  @response
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2227
2228
2229
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 2227

def update!(**args)
  @response = args[:response] if args.key?(:response)
end