Class: Google::Apis::MerchantapiAccountsV1beta::ListGbpAccountsResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/merchantapi_accounts_v1beta/classes.rb,
lib/google/apis/merchantapi_accounts_v1beta/representations.rb,
lib/google/apis/merchantapi_accounts_v1beta/representations.rb

Overview

Response message for the ListGbpAccounts method.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListGbpAccountsResponse

Returns a new instance of ListGbpAccountsResponse.



2351
2352
2353
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 2351

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#gbp_accountsArray<Google::Apis::MerchantapiAccountsV1beta::GbpAccount>

The GBP accounts from the specified merchant in the specified country. Corresponds to the JSON property gbpAccounts



2343
2344
2345
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 2343

def gbp_accounts
  @gbp_accounts
end

#next_page_tokenString

A token, which can be sent as page_token to retrieve the next page. If this field is omitted, there are no subsequent pages. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


2349
2350
2351
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 2349

def next_page_token
  @next_page_token
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2356
2357
2358
2359
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 2356

def update!(**args)
  @gbp_accounts = args[:gbp_accounts] if args.key?(:gbp_accounts)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
end