Class: Google::Apis::MerchantapiAccountsV1beta::ListSubAccountsResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/merchantapi_accounts_v1beta/classes.rb,
lib/google/apis/merchantapi_accounts_v1beta/representations.rb,
lib/google/apis/merchantapi_accounts_v1beta/representations.rb

Overview

Response message for the ListSubAccounts method.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListSubAccountsResponse

Returns a new instance of ListSubAccountsResponse.



2481
2482
2483
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 2481

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#accountsArray<Google::Apis::MerchantapiAccountsV1beta::Account>

The accounts for which the given parent account is an aggregator. Corresponds to the JSON property accounts



2473
2474
2475
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 2473

def accounts
  @accounts
end

#next_page_tokenString

A token, which can be sent as page_token to retrieve the next page. If this field is omitted, there are no subsequent pages. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


2479
2480
2481
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 2479

def next_page_token
  @next_page_token
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2486
2487
2488
2489
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 2486

def update!(**args)
  @accounts = args[:accounts] if args.key?(:accounts)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
end