Class: Google::Apis::MerchantapiAccountsV1beta::LocationIdSet

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/merchantapi_accounts_v1beta/classes.rb,
lib/google/apis/merchantapi_accounts_v1beta/representations.rb,
lib/google/apis/merchantapi_accounts_v1beta/representations.rb

Overview

A list of location ID sets. Must be non-empty. Can only be set if all other fields are not set.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ LocationIdSet

Returns a new instance of LocationIdSet.



2568
2569
2570
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 2568

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#location_idsArray<String>

Required. A non-empty list of location IDs. They must all be of the same location type (For example, state). Corresponds to the JSON property locationIds

Returns:

  • (Array<String>)


2566
2567
2568
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 2566

def location_ids
  @location_ids
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2573
2574
2575
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 2573

def update!(**args)
  @location_ids = args[:location_ids] if args.key?(:location_ids)
end