Class: Google::Apis::MerchantapiAccountsV1beta::PhoneNumber

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/merchantapi_accounts_v1beta/classes.rb,
lib/google/apis/merchantapi_accounts_v1beta/representations.rb,
lib/google/apis/merchantapi_accounts_v1beta/representations.rb

Overview

An object representing a phone number, suitable as an API wire format. This representation: - should not be used for locale-specific formatting of a phone number, such as "+1 (650) 253-0000 ext. 123" - is not designed for efficient storage - may not be suitable for dialing - specialized libraries (see references) should be used to parse the number for that purpose To do something meaningful with this number, such as format it for various use-cases, convert it to an i18n.phonenumbers.PhoneNumber object first. For instance, in Java this would be: com.google.type.PhoneNumber wireProto = com.google.type. PhoneNumber.newBuilder().build(); com.google.i18n.phonenumbers.Phonenumber. PhoneNumber phoneNumber = PhoneNumberUtil.getInstance().parse(wireProto. getE164Number(), "ZZ"); if (!wireProto.getExtension().isEmpty()) phoneNumber. setExtension(wireProto.getExtension()); Reference(s): - https://github.com/ google/libphonenumber

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PhoneNumber

Returns a new instance of PhoneNumber.



2928
2929
2930
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 2928

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#e164_numberString

The phone number, represented as a leading plus sign ('+'), followed by a phone number that uses a relaxed ITU E.164 format consisting of the country calling code (1 to 3 digits) and the subscriber number, with no additional spaces or formatting. For example: - correct: "+15552220123" - incorrect: "+1 ( 555) 222-01234 x123" The ITU E.164 format limits the latter to 12 digits, but in practice not all countries respect that, so we relax that restriction here. National-only numbers are not allowed. References: - https://www.itu.int/rec/T- REC-E.164-201011-I - https://en.wikipedia.org/wiki/E.164. - https://en. wikipedia.org/wiki/List_of_country_calling_codes Corresponds to the JSON property e164Number

Returns:

  • (String)


2903
2904
2905
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 2903

def e164_number
  @e164_number
end

#extensionString

The phone number's extension. The extension is not standardized in ITU recommendations, except for being defined as a series of numbers with a maximum length of 40 digits. Other than digits, some other dialing characters such as ',' (indicating a wait) or '#' may be stored here. Note that no regions currently use extensions with short codes, so this field is normally only set in conjunction with an E.164 number. It is held separately from the E. 164 number to allow for short code extensions in the future. Corresponds to the JSON property extension

Returns:

  • (String)


2914
2915
2916
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 2914

def extension
  @extension
end

#short_codeGoogle::Apis::MerchantapiAccountsV1beta::ShortCode

An object representing a short code, which is a phone number that is typically much shorter than regular phone numbers and can be used to address messages in MMS and SMS systems, as well as for abbreviated dialing (For example "Text 611 to see how many minutes you have remaining on your plan."). Short codes are restricted to a region and are not internationally dialable, which means the same short code can exist in different regions, with different usage and pricing, even if those regions share the same country calling code (For example: US and CA). Corresponds to the JSON property shortCode



2926
2927
2928
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 2926

def short_code
  @short_code
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2933
2934
2935
2936
2937
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 2933

def update!(**args)
  @e164_number = args[:e164_number] if args.key?(:e164_number)
  @extension = args[:extension] if args.key?(:extension)
  @short_code = args[:short_code] if args.key?(:short_code)
end