Class: Google::Apis::MerchantapiAccountsV1beta::Policy

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/merchantapi_accounts_v1beta/classes.rb,
lib/google/apis/merchantapi_accounts_v1beta/representations.rb,
lib/google/apis/merchantapi_accounts_v1beta/representations.rb

Overview

The available policies.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Policy

Returns a new instance of Policy.



2982
2983
2984
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 2982

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#daysFixnum

The number of days items can be returned after delivery, where one day is defined as 24 hours after the delivery timestamp. Required for NUMBER_OF_DAYS_AFTER_DELIVERY returns. Corresponds to the JSON property days

Returns:

  • (Fixnum)


2975
2976
2977
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 2975

def days
  @days
end

#typeString

Policy type. Corresponds to the JSON property type

Returns:

  • (String)


2980
2981
2982
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 2980

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2987
2988
2989
2990
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 2987

def update!(**args)
  @days = args[:days] if args.key?(:days)
  @type = args[:type] if args.key?(:type)
end