Class: Google::Apis::MerchantapiAccountsV1beta::PostalCodeArea

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/merchantapi_accounts_v1beta/classes.rb,
lib/google/apis/merchantapi_accounts_v1beta/representations.rb,
lib/google/apis/merchantapi_accounts_v1beta/representations.rb

Overview

A list of postal codes that defines the region area. Note: All regions defined using postal codes are accessible through the account's ShippingSettings. postalCodeGroups resource.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PostalCodeArea

Returns a new instance of PostalCodeArea.



3145
3146
3147
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 3145

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#postal_codesArray<Google::Apis::MerchantapiAccountsV1beta::PostalCodeRange>

Required. A range of postal codes. Corresponds to the JSON property postalCodes



3137
3138
3139
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 3137

def postal_codes
  @postal_codes
end

#region_codeString

Required. CLDR territory code or the country the postal code group applies to. Corresponds to the JSON property regionCode

Returns:

  • (String)


3143
3144
3145
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 3143

def region_code
  @region_code
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3150
3151
3152
3153
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 3150

def update!(**args)
  @postal_codes = args[:postal_codes] if args.key?(:postal_codes)
  @region_code = args[:region_code] if args.key?(:region_code)
end