Class: Google::Apis::MerchantapiAccountsV1beta::PostalCodeRange

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/merchantapi_accounts_v1beta/classes.rb,
lib/google/apis/merchantapi_accounts_v1beta/representations.rb,
lib/google/apis/merchantapi_accounts_v1beta/representations.rb

Overview

A range of postal codes that defines the region area.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PostalCodeRange

Returns a new instance of PostalCodeRange.



3178
3179
3180
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 3178

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#beginString

Required. A postal code or a pattern of the form prefix* denoting the inclusive lower bound of the range defining the area. Examples values: 94108, 9410*, 9*. Corresponds to the JSON property begin

Returns:

  • (String)


3165
3166
3167
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 3165

def begin
  @begin
end

#endString

Optional. A postal code or a pattern of the form prefix* denoting the inclusive upper bound of the range defining the area. It must have the same length as postalCodeRangeBegin: if postalCodeRangeBegin is a postal code then postalCodeRangeEnd must be a postal code too; if postalCodeRangeBegin is a pattern then postalCodeRangeEnd must be a pattern with the same prefix length. Optional: if not set, then the area is defined as being all the postal codes matching postalCodeRangeBegin. Corresponds to the JSON property end

Returns:

  • (String)


3176
3177
3178
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 3176

def end
  @end
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3183
3184
3185
3186
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 3183

def update!(**args)
  @begin = args[:begin] if args.key?(:begin)
  @end = args[:end] if args.key?(:end)
end