Class: Google::Apis::MerchantapiAccountsV1beta::ProductChange

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/merchantapi_accounts_v1beta/classes.rb,
lib/google/apis/merchantapi_accounts_v1beta/representations.rb,
lib/google/apis/merchantapi_accounts_v1beta/representations.rb

Overview

The change that happened to the product including old value, new value, country code as the region code and reporting context.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ProductChange

Returns a new instance of ProductChange.



3256
3257
3258
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 3256

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#new_valueString

The new value of the changed resource or attribute. If empty, it means that the product was deleted. Will have one of these values : (approved, pending , disapproved, `) Corresponds to the JSON propertynewValue`

Returns:

  • (String)


3232
3233
3234
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 3232

def new_value
  @new_value
end

#old_valueString

The old value of the changed resource or attribute. If empty, it means that the product was created. Will have one of these values : (approved, pending , disapproved, `) Corresponds to the JSON propertyoldValue`

Returns:

  • (String)


3239
3240
3241
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 3239

def old_value
  @old_value
end

#region_codeString

Countries that have the change (if applicable). Represented in the ISO 3166 format. Corresponds to the JSON property regionCode

Returns:

  • (String)


3245
3246
3247
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 3245

def region_code
  @region_code
end

#reporting_contextString

Reporting contexts that have the change (if applicable). Currently this field supports only (SHOPPING_ADS, LOCAL_INVENTORY_ADS, YOUTUBE_SHOPPING, YOUTUBE_CHECKOUT, YOUTUBE_AFFILIATE) from the enum value ReportingContextEnum Corresponds to the JSON property reportingContext

Returns:

  • (String)


3254
3255
3256
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 3254

def reporting_context
  @reporting_context
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3261
3262
3263
3264
3265
3266
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 3261

def update!(**args)
  @new_value = args[:new_value] if args.key?(:new_value)
  @old_value = args[:old_value] if args.key?(:old_value)
  @region_code = args[:region_code] if args.key?(:region_code)
  @reporting_context = args[:reporting_context] if args.key?(:reporting_context)
end