Class: Google::Apis::MerchantapiAccountsV1beta::Requirement
- Inherits:
-
Object
- Object
- Google::Apis::MerchantapiAccountsV1beta::Requirement
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/merchantapi_accounts_v1beta/classes.rb,
lib/google/apis/merchantapi_accounts_v1beta/representations.rb,
lib/google/apis/merchantapi_accounts_v1beta/representations.rb
Overview
Defines a requirement specified for participation in the program.
Instance Attribute Summary collapse
-
#affected_region_codes ⇒ Array<String>
Output only.
-
#documentation_uri ⇒ String
Output only.
-
#title ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Requirement
constructor
A new instance of Requirement.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Requirement
Returns a new instance of Requirement.
3740 3741 3742 |
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 3740 def initialize(**args) update!(**args) end |
Instance Attribute Details
#affected_region_codes ⇒ Array<String>
Output only. The regions that are currently affected by this requirement not
being met. Region codes are defined by CLDR. This
is either a country where the program applies specifically to that country or
001 when the program applies globally.
Corresponds to the JSON property affectedRegionCodes
3728 3729 3730 |
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 3728 def affected_region_codes @affected_region_codes end |
#documentation_uri ⇒ String
Output only. The URL of a help page describing the requirement.
Corresponds to the JSON property documentationUri
3733 3734 3735 |
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 3733 def documentation_uri @documentation_uri end |
#title ⇒ String
Output only. Name of the requirement.
Corresponds to the JSON property title
3738 3739 3740 |
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 3738 def title @title end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3745 3746 3747 3748 3749 |
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 3745 def update!(**args) @affected_region_codes = args[:affected_region_codes] if args.key?(:affected_region_codes) @documentation_uri = args[:documentation_uri] if args.key?(:documentation_uri) @title = args[:title] if args.key?(:title) end |