Class: Google::Apis::MerchantapiAccountsV1beta::ReturnShippingFee

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/merchantapi_accounts_v1beta/classes.rb,
lib/google/apis/merchantapi_accounts_v1beta/representations.rb,
lib/google/apis/merchantapi_accounts_v1beta/representations.rb

Overview

The return shipping fee. This can either be a fixed fee or a boolean to indicate that the customer pays the actual shipping cost.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ReturnShippingFee

Returns a new instance of ReturnShippingFee.



3787
3788
3789
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 3787

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#fixed_feeGoogle::Apis::MerchantapiAccountsV1beta::Price

The price represented as a number and currency. Corresponds to the JSON property fixedFee



3780
3781
3782
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 3780

def fixed_fee
  @fixed_fee
end

#typeString

Required. Type of return shipping fee. Corresponds to the JSON property type

Returns:

  • (String)


3785
3786
3787
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 3785

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3792
3793
3794
3795
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 3792

def update!(**args)
  @fixed_fee = args[:fixed_fee] if args.key?(:fixed_fee)
  @type = args[:type] if args.key?(:type)
end