Class: Google::Apis::MerchantapiAccountsV1beta::SeasonalOverride

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/merchantapi_accounts_v1beta/classes.rb,
lib/google/apis/merchantapi_accounts_v1beta/representations.rb,
lib/google/apis/merchantapi_accounts_v1beta/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SeasonalOverride

Returns a new instance of SeasonalOverride.



3875
3876
3877
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 3875

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#end_dateGoogle::Apis::MerchantapiAccountsV1beta::Date

Represents a whole or partial calendar date, such as a birthday. The time of day and time zone are either specified elsewhere or are insignificant. The date is relative to the Gregorian Calendar. This can represent one of the following: * A full date, with non-zero year, month, and day values. * A month and day, with a zero year (for example, an anniversary). * A year on its own, with a zero month and a zero day. * A year and month, with a zero day (for example, a credit card expiration date). Related types: * google.type. TimeOfDay * google.type.DateTime * google.protobuf.Timestamp Corresponds to the JSON property endDate



3839
3840
3841
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 3839

def end_date
  @end_date
end

#labelString

Required. Display name of this seasonal override in Merchant Center. Corresponds to the JSON property label

Returns:

  • (String)


3844
3845
3846
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 3844

def label
  @label
end

#return_daysFixnum

Number of days (from the delivery date) that the product can be returned. Corresponds to the JSON property returnDays

Returns:

  • (Fixnum)


3849
3850
3851
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 3849

def return_days
  @return_days
end

#return_until_dateGoogle::Apis::MerchantapiAccountsV1beta::Date

Represents a whole or partial calendar date, such as a birthday. The time of day and time zone are either specified elsewhere or are insignificant. The date is relative to the Gregorian Calendar. This can represent one of the following: * A full date, with non-zero year, month, and day values. * A month and day, with a zero year (for example, an anniversary). * A year on its own, with a zero month and a zero day. * A year and month, with a zero day (for example, a credit card expiration date). Related types: * google.type. TimeOfDay * google.type.DateTime * google.protobuf.Timestamp Corresponds to the JSON property returnUntilDate



3861
3862
3863
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 3861

def return_until_date
  @return_until_date
end

#start_dateGoogle::Apis::MerchantapiAccountsV1beta::Date

Represents a whole or partial calendar date, such as a birthday. The time of day and time zone are either specified elsewhere or are insignificant. The date is relative to the Gregorian Calendar. This can represent one of the following: * A full date, with non-zero year, month, and day values. * A month and day, with a zero year (for example, an anniversary). * A year on its own, with a zero month and a zero day. * A year and month, with a zero day (for example, a credit card expiration date). Related types: * google.type. TimeOfDay * google.type.DateTime * google.protobuf.Timestamp Corresponds to the JSON property startDate



3873
3874
3875
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 3873

def start_date
  @start_date
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3880
3881
3882
3883
3884
3885
3886
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 3880

def update!(**args)
  @end_date = args[:end_date] if args.key?(:end_date)
  @label = args[:label] if args.key?(:label)
  @return_days = args[:return_days] if args.key?(:return_days)
  @return_until_date = args[:return_until_date] if args.key?(:return_until_date)
  @start_date = args[:start_date] if args.key?(:start_date)
end