Class: Google::Apis::MerchantapiAccountsV1beta::Service
- Inherits:
-
Object
- Object
- Google::Apis::MerchantapiAccountsV1beta::Service
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/merchantapi_accounts_v1beta/classes.rb,
lib/google/apis/merchantapi_accounts_v1beta/representations.rb,
lib/google/apis/merchantapi_accounts_v1beta/representations.rb
Overview
Shipping service.
Instance Attribute Summary collapse
-
#active ⇒ Boolean
(also: #active?)
Required.
-
#currency_code ⇒ String
Required.
-
#delivery_countries ⇒ Array<String>
Required.
-
#delivery_time ⇒ Google::Apis::MerchantapiAccountsV1beta::DeliveryTime
Time spent in various aspects from order to the delivery of the product.
-
#loyalty_programs ⇒ Array<Google::Apis::MerchantapiAccountsV1beta::LoyaltyProgram>
Optional.
-
#minimum_order_value ⇒ Google::Apis::MerchantapiAccountsV1beta::Price
The price represented as a number and currency.
-
#minimum_order_value_table ⇒ Google::Apis::MerchantapiAccountsV1beta::MinimumOrderValueTable
Table of per store minimum order values for the pickup fulfillment type.
-
#rate_groups ⇒ Array<Google::Apis::MerchantapiAccountsV1beta::RateGroup>
Optional.
-
#service_name ⇒ String
Required.
-
#shipment_type ⇒ String
Optional.
-
#store_config ⇒ Google::Apis::MerchantapiAccountsV1beta::StoreConfig
A list of stores your products are delivered from.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Service
constructor
A new instance of Service.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Service
Returns a new instance of Service.
3954 3955 3956 |
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 3954 def initialize(**args) update!(**args) end |
Instance Attribute Details
#active ⇒ Boolean Also known as: active?
Required. A boolean exposing the active status of the shipping service.
Corresponds to the JSON property active
3896 3897 3898 |
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 3896 def active @active end |
#currency_code ⇒ String
Required. The CLDR code of the currency to which this service applies. Must
match that of the prices in rate groups.
Corresponds to the JSON property currencyCode
3903 3904 3905 |
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 3903 def currency_code @currency_code end |
#delivery_countries ⇒ Array<String>
Required. The CLDR territory code of the countries to which the service
applies.
Corresponds to the JSON property deliveryCountries
3909 3910 3911 |
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 3909 def delivery_countries @delivery_countries end |
#delivery_time ⇒ Google::Apis::MerchantapiAccountsV1beta::DeliveryTime
Time spent in various aspects from order to the delivery of the product.
Corresponds to the JSON property deliveryTime
3914 3915 3916 |
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 3914 def delivery_time @delivery_time end |
#loyalty_programs ⇒ Array<Google::Apis::MerchantapiAccountsV1beta::LoyaltyProgram>
Optional. Loyalty programs that this shipping service is limited to.
Corresponds to the JSON property loyaltyPrograms
3919 3920 3921 |
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 3919 def loyalty_programs @loyalty_programs end |
#minimum_order_value ⇒ Google::Apis::MerchantapiAccountsV1beta::Price
The price represented as a number and currency.
Corresponds to the JSON property minimumOrderValue
3924 3925 3926 |
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 3924 def minimum_order_value @minimum_order_value end |
#minimum_order_value_table ⇒ Google::Apis::MerchantapiAccountsV1beta::MinimumOrderValueTable
Table of per store minimum order values for the pickup fulfillment type.
Corresponds to the JSON property minimumOrderValueTable
3929 3930 3931 |
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 3929 def minimum_order_value_table @minimum_order_value_table end |
#rate_groups ⇒ Array<Google::Apis::MerchantapiAccountsV1beta::RateGroup>
Optional. Shipping rate group definitions. Only the last one is allowed to
have an empty applicable_shipping_labels, which means "everything else". The
other applicable_shipping_labels must not overlap.
Corresponds to the JSON property rateGroups
3936 3937 3938 |
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 3936 def rate_groups @rate_groups end |
#service_name ⇒ String
Required. Free-form name of the service. Must be unique within target account.
Corresponds to the JSON property serviceName
3941 3942 3943 |
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 3941 def service_name @service_name end |
#shipment_type ⇒ String
Optional. Type of locations this service ships orders to.
Corresponds to the JSON property shipmentType
3946 3947 3948 |
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 3946 def shipment_type @shipment_type end |
#store_config ⇒ Google::Apis::MerchantapiAccountsV1beta::StoreConfig
A list of stores your products are delivered from. This is only valid for the
local delivery shipment type.
Corresponds to the JSON property storeConfig
3952 3953 3954 |
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 3952 def store_config @store_config end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3959 3960 3961 3962 3963 3964 3965 3966 3967 3968 3969 3970 3971 |
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 3959 def update!(**args) @active = args[:active] if args.key?(:active) @currency_code = args[:currency_code] if args.key?(:currency_code) @delivery_countries = args[:delivery_countries] if args.key?(:delivery_countries) @delivery_time = args[:delivery_time] if args.key?(:delivery_time) @loyalty_programs = args[:loyalty_programs] if args.key?(:loyalty_programs) @minimum_order_value = args[:minimum_order_value] if args.key?(:minimum_order_value) @minimum_order_value_table = args[:minimum_order_value_table] if args.key?(:minimum_order_value_table) @rate_groups = args[:rate_groups] if args.key?(:rate_groups) @service_name = args[:service_name] if args.key?(:service_name) @shipment_type = args[:shipment_type] if args.key?(:shipment_type) @store_config = args[:store_config] if args.key?(:store_config) end |