Class: Google::Apis::MerchantapiAccountsV1beta::StoreCodeSetWithMov

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/merchantapi_accounts_v1beta/classes.rb,
lib/google/apis/merchantapi_accounts_v1beta/representations.rb,
lib/google/apis/merchantapi_accounts_v1beta/representations.rb

Overview

A list of store code sets sharing the same minimum order value. At least two sets are required and the last one must be empty, which signifies 'MOV for all other stores'. Each store code can only appear once across all the sets. All prices within a service must have the same currency.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ StoreCodeSetWithMov

Returns a new instance of StoreCodeSetWithMov.



4106
4107
4108
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 4106

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#store_codesArray<String>

Optional. A list of unique store codes or empty for the catch all. Corresponds to the JSON property storeCodes

Returns:

  • (Array<String>)


4099
4100
4101
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 4099

def store_codes
  @store_codes
end

#valueGoogle::Apis::MerchantapiAccountsV1beta::Price

The price represented as a number and currency. Corresponds to the JSON property value



4104
4105
4106
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 4104

def value
  @value
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4111
4112
4113
4114
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 4111

def update!(**args)
  @store_codes = args[:store_codes] if args.key?(:store_codes)
  @value = args[:value] if args.key?(:value)
end