Class: Google::Apis::MerchantapiAccountsV1beta::Table

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/merchantapi_accounts_v1beta/classes.rb,
lib/google/apis/merchantapi_accounts_v1beta/representations.rb,
lib/google/apis/merchantapi_accounts_v1beta/representations.rb

Overview

A table defining the rate group, when single_value is not expressive enough.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Table

Returns a new instance of Table.



4179
4180
4181
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 4179

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#column_headersGoogle::Apis::MerchantapiAccountsV1beta::Headers

A non-empty list of row or column headers for a table. Exactly one of prices, weights, num_items, postal_code_group_names, or location must be set. Corresponds to the JSON property columnHeaders



4160
4161
4162
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 4160

def column_headers
  @column_headers
end

#nameString

Name of the table. Required for subtables, ignored for the main table. Corresponds to the JSON property name

Returns:

  • (String)


4165
4166
4167
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 4165

def name
  @name
end

#row_headersGoogle::Apis::MerchantapiAccountsV1beta::Headers

A non-empty list of row or column headers for a table. Exactly one of prices, weights, num_items, postal_code_group_names, or location must be set. Corresponds to the JSON property rowHeaders



4171
4172
4173
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 4171

def row_headers
  @row_headers
end

#rowsArray<Google::Apis::MerchantapiAccountsV1beta::Row>

Required. The list of rows that constitute the table. Must have the same length as row_headers. Corresponds to the JSON property rows



4177
4178
4179
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 4177

def rows
  @rows
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4184
4185
4186
4187
4188
4189
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 4184

def update!(**args)
  @column_headers = args[:column_headers] if args.key?(:column_headers)
  @name = args[:name] if args.key?(:name)
  @row_headers = args[:row_headers] if args.key?(:row_headers)
  @rows = args[:rows] if args.key?(:rows)
end