Class: Google::Apis::MerchantapiAccountsV1beta::TransitTable

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/merchantapi_accounts_v1beta/classes.rb,
lib/google/apis/merchantapi_accounts_v1beta/representations.rb,
lib/google/apis/merchantapi_accounts_v1beta/representations.rb

Overview

Transit time table, number of business days spent in transit based on row and column dimensions. Either min_transit_days, max_transit_days or transit_time_table can be set, but not both.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TransitTable

Returns a new instance of TransitTable.



4372
4373
4374
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 4372

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#postal_code_group_namesArray<String>

Required. A list of region names Region.name . The last value can be "all other locations". Example: ["zone 1", "zone 2", "all other locations"]. The referred postal code groups must match the delivery country of the service. Corresponds to the JSON property postalCodeGroupNames

Returns:

  • (Array<String>)


4356
4357
4358
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 4356

def postal_code_group_names
  @postal_code_group_names
end

#rowsArray<Google::Apis::MerchantapiAccountsV1beta::TransitTimeRow>

Required. If there's only one dimension set of postal_code_group_names or transit_time_labels, there are multiple rows each with one value for that dimension. If there are two dimensions, each row corresponds to a postal_code_group_names, and columns (values) to a transit_time_labels. Corresponds to the JSON property rows



4364
4365
4366
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 4364

def rows
  @rows
end

#transit_time_labelsArray<String>

Required. A list of transit time labels. The last value can be "all other labels". Example: ["food", "electronics", "all other labels"]. Corresponds to the JSON property transitTimeLabels

Returns:

  • (Array<String>)


4370
4371
4372
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 4370

def transit_time_labels
  @transit_time_labels
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4377
4378
4379
4380
4381
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 4377

def update!(**args)
  @postal_code_group_names = args[:postal_code_group_names] if args.key?(:postal_code_group_names)
  @rows = args[:rows] if args.key?(:rows)
  @transit_time_labels = args[:transit_time_labels] if args.key?(:transit_time_labels)
end