Class: Google::Apis::MerchantapiAccountsV1beta::TransitTimeRow
- Inherits:
-
Object
- Object
- Google::Apis::MerchantapiAccountsV1beta::TransitTimeRow
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/merchantapi_accounts_v1beta/classes.rb,
lib/google/apis/merchantapi_accounts_v1beta/representations.rb,
lib/google/apis/merchantapi_accounts_v1beta/representations.rb
Overview
If there's only one dimension set of postal_code_group_names or
transit_time_labels, there are multiple rows each with one value for that
dimension. If there are two dimensions, each row corresponds to a
postal_code_group_names, and columns (values) to a transit_time_labels.
Instance Attribute Summary collapse
Instance Method Summary collapse
-
#initialize(**args) ⇒ TransitTimeRow
constructor
A new instance of TransitTimeRow.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ TransitTimeRow
Returns a new instance of TransitTimeRow.
4390 4391 4392 |
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 4390 def initialize(**args) update!(**args) end |
Instance Attribute Details
#values ⇒ Array<Google::Apis::MerchantapiAccountsV1beta::TransitTimeValue>
Required. Transit time range (min-max) in business days.
Corresponds to the JSON property values
4388 4389 4390 |
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 4388 def values @values end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4395 4396 4397 |
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 4395 def update!(**args) @values = args[:values] if args.key?(:values) end |