Class: Google::Apis::MerchantapiAccountsV1beta::Warehouse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/merchantapi_accounts_v1beta/classes.rb,
lib/google/apis/merchantapi_accounts_v1beta/representations.rb,
lib/google/apis/merchantapi_accounts_v1beta/representations.rb

Overview

A fulfillment warehouse, which stores and handles inventory.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Warehouse

Returns a new instance of Warehouse.



4657
4658
4659
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 4657

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#business_day_configGoogle::Apis::MerchantapiAccountsV1beta::BusinessDayConfig

Business days of the warehouse. Corresponds to the JSON property businessDayConfig



4631
4632
4633
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 4631

def business_day_config
  @business_day_config
end

#cutoff_timeGoogle::Apis::MerchantapiAccountsV1beta::WarehouseCutoffTime

The latest time of day that an order can be accepted and begin processing. Later orders will be processed in the next day. The time is based on the warehouse postal code. Corresponds to the JSON property cutoffTime



4638
4639
4640
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 4638

def cutoff_time
  @cutoff_time
end

#handling_daysFixnum

Required. The number of days it takes for this warehouse to pack up and ship an item. This is on the warehouse level, but can be overridden on the offer level based on the attributes of an item. Corresponds to the JSON property handlingDays

Returns:

  • (Fixnum)


4645
4646
4647
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 4645

def handling_days
  @handling_days
end

#nameString

Required. The name of the warehouse. Must be unique within account. Corresponds to the JSON property name

Returns:

  • (String)


4650
4651
4652
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 4650

def name
  @name
end

#shipping_addressGoogle::Apis::MerchantapiAccountsV1beta::Address

Shipping address of the warehouse. Corresponds to the JSON property shippingAddress



4655
4656
4657
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 4655

def shipping_address
  @shipping_address
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4662
4663
4664
4665
4666
4667
4668
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 4662

def update!(**args)
  @business_day_config = args[:business_day_config] if args.key?(:business_day_config)
  @cutoff_time = args[:cutoff_time] if args.key?(:cutoff_time)
  @handling_days = args[:handling_days] if args.key?(:handling_days)
  @name = args[:name] if args.key?(:name)
  @shipping_address = args[:shipping_address] if args.key?(:shipping_address)
end