Class: Google::Apis::MerchantapiAccountsV1beta::Accepted
- Inherits:
-
Object
- Object
- Google::Apis::MerchantapiAccountsV1beta::Accepted
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/merchantapi_accounts_v1beta/classes.rb,
lib/google/apis/merchantapi_accounts_v1beta/representations.rb,
lib/google/apis/merchantapi_accounts_v1beta/representations.rb
Overview
Describes the accepted terms of service.
Instance Attribute Summary collapse
-
#accepted_by ⇒ String
Required.
-
#terms_of_service ⇒ String
Required.
-
#valid_until ⇒ Google::Apis::MerchantapiAccountsV1beta::Date
Represents a whole or partial calendar date, such as a birthday.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Accepted
constructor
A new instance of Accepted.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Accepted
Returns a new instance of Accepted.
113 114 115 |
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 113 def initialize(**args) update!(**args) end |
Instance Attribute Details
#accepted_by ⇒ String
Required. The account where the acceptance was recorded. This can be the
account itself or, in the case of subaccounts, the advanced account.
Corresponds to the JSON property acceptedBy
94 95 96 |
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 94 def accepted_by @accepted_by end |
#terms_of_service ⇒ String
Required. The accepted termsOfService.
Corresponds to the JSON property termsOfService
99 100 101 |
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 99 def terms_of_service @terms_of_service end |
#valid_until ⇒ Google::Apis::MerchantapiAccountsV1beta::Date
Represents a whole or partial calendar date, such as a birthday. The time of
day and time zone are either specified elsewhere or are insignificant. The
date is relative to the Gregorian Calendar. This can represent one of the
following: * A full date, with non-zero year, month, and day values. * A month
and day, with a zero year (for example, an anniversary). * A year on its own,
with a zero month and a zero day. * A year and month, with a zero day (for
example, a credit card expiration date). Related types: * google.type.
TimeOfDay * google.type.DateTime * google.protobuf.Timestamp
Corresponds to the JSON property validUntil
111 112 113 |
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 111 def valid_until @valid_until end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
118 119 120 121 122 |
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 118 def update!(**args) @accepted_by = args[:accepted_by] if args.key?(:accepted_by) @terms_of_service = args[:terms_of_service] if args.key?(:terms_of_service) @valid_until = args[:valid_until] if args.key?(:valid_until) end |