Class: Google::Apis::MerchantapiAccountsV1beta::AccountRelationship
- Inherits:
-
Object
- Object
- Google::Apis::MerchantapiAccountsV1beta::AccountRelationship
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/merchantapi_accounts_v1beta/classes.rb,
lib/google/apis/merchantapi_accounts_v1beta/representations.rb,
lib/google/apis/merchantapi_accounts_v1beta/representations.rb
Overview
The AccountRelationship message defines a formal connection between a
merchant's account and a service provider's account. This relationship enables
the provider to offer specific services to the business, such as product
management or campaign management. It specifies the access rights and
permissions to the business's data relevant to those services. Establishing an
account relationship involves linking the merchant's account with a provider's
account. The provider could be another Google account (like Google Ads or
Google My Business) or a third-party platform (such as Shopify or WooCommerce).
Instance Attribute Summary collapse
-
#account_id_alias ⇒ String
Optional.
-
#name ⇒ String
Identifier.
-
#provider ⇒ String
Immutable.
-
#provider_display_name ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ AccountRelationship
constructor
A new instance of AccountRelationship.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ AccountRelationship
Returns a new instance of AccountRelationship.
315 316 317 |
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 315 def initialize(**args) update!(**args) end |
Instance Attribute Details
#account_id_alias ⇒ String
Optional. An optional alias you can assign to this account relationship. This
alias acts as a convenient identifier for your own reference and management.
It must be unique among all your account relationships with the same provider.
For example, you might use account_id_alias to assign a friendly name to
this relationship for easier identification in your systems.
Corresponds to the JSON property accountIdAlias
294 295 296 |
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 294 def account_id_alias @account_id_alias end |
#name ⇒ String
Identifier. The resource name of the account relationship. Format: accounts/
account/relationships/relationship`. For example,accounts/123456/
relationships/567890.
Corresponds to the JSON propertyname`
301 302 303 |
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 301 def name @name end |
#provider ⇒ String
Immutable. The provider of the service. Either the reference to an account
such as providers/123 or a well-known service provider (one of providers/
GOOGLE_ADS or providers/GOOGLE_BUSINESS_PROFILE).
Corresponds to the JSON property provider
308 309 310 |
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 308 def provider @provider end |
#provider_display_name ⇒ String
Output only. The human-readable display name of the provider account.
Corresponds to the JSON property providerDisplayName
313 314 315 |
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 313 def provider_display_name @provider_display_name end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
320 321 322 323 324 325 |
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 320 def update!(**args) @account_id_alias = args[:account_id_alias] if args.key?(:account_id_alias) @name = args[:name] if args.key?(:name) @provider = args[:provider] if args.key?(:provider) @provider_display_name = args[:provider_display_name] if args.key?(:provider_display_name) end |