Class: Google::Apis::MerchantapiAccountsV1beta::AddUser
- Inherits:
-
Object
- Object
- Google::Apis::MerchantapiAccountsV1beta::AddUser
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/merchantapi_accounts_v1beta/classes.rb,
lib/google/apis/merchantapi_accounts_v1beta/representations.rb,
lib/google/apis/merchantapi_accounts_v1beta/representations.rb
Overview
Instruction for adding a user to the account during creation.
Instance Attribute Summary collapse
-
#user ⇒ Google::Apis::MerchantapiAccountsV1beta::User
The
Userresource represents a user associated with a Merchant Center account. -
#user_id ⇒ String
Required.
-
#verification_mail_settings ⇒ Google::Apis::MerchantapiAccountsV1beta::VerificationMailSettings
Settings related to the verification email that is sent after adding a user.
Instance Method Summary collapse
-
#initialize(**args) ⇒ AddUser
constructor
A new instance of AddUser.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ AddUser
Returns a new instance of AddUser.
526 527 528 |
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 526 def initialize(**args) update!(**args) end |
Instance Attribute Details
#user ⇒ Google::Apis::MerchantapiAccountsV1beta::User
The User resource represents a user associated with a Merchant Center
account. It is used to manage user permissions and access rights within the
account. For more information, see Frequently asked questions about people
and access levels.
Corresponds to the JSON property user
514 515 516 |
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 514 def user @user end |
#user_id ⇒ String
Required. The email address of the user (for example, john.doe@gmail.com).
Corresponds to the JSON property userId
519 520 521 |
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 519 def user_id @user_id end |
#verification_mail_settings ⇒ Google::Apis::MerchantapiAccountsV1beta::VerificationMailSettings
Settings related to the verification email that is sent after adding a user.
Corresponds to the JSON property verificationMailSettings
524 525 526 |
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 524 def verification_mail_settings @verification_mail_settings end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
531 532 533 534 535 |
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 531 def update!(**args) @user = args[:user] if args.key?(:user) @user_id = args[:user_id] if args.key?(:user_id) @verification_mail_settings = args[:verification_mail_settings] if args.key?(:verification_mail_settings) end |