Class: Google::Apis::MerchantapiAccountsV1beta::AutofeedSettings
- Inherits:
-
Object
- Object
- Google::Apis::MerchantapiAccountsV1beta::AutofeedSettings
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/merchantapi_accounts_v1beta/classes.rb,
lib/google/apis/merchantapi_accounts_v1beta/representations.rb,
lib/google/apis/merchantapi_accounts_v1beta/representations.rb
Overview
Collection of information related to the autofeed settings.
Instance Attribute Summary collapse
-
#eligible ⇒ Boolean
(also: #eligible?)
Output only.
-
#enable_products ⇒ Boolean
(also: #enable_products?)
Required.
-
#name ⇒ String
Identifier.
Instance Method Summary collapse
-
#initialize(**args) ⇒ AutofeedSettings
constructor
A new instance of AutofeedSettings.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ AutofeedSettings
Returns a new instance of AutofeedSettings.
633 634 635 |
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 633 def initialize(**args) update!(**args) end |
Instance Attribute Details
#eligible ⇒ Boolean Also known as: eligible?
Output only. Determines whether the business is eligible for being enrolled
into an autofeed.
Corresponds to the JSON property eligible
612 613 614 |
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 612 def eligible @eligible end |
#enable_products ⇒ Boolean Also known as: enable_products?
Required. Enables or disables product crawling through the autofeed for the
given account. Autofeed accounts must meet certain conditions, which can be checked through
the eligible field. The account must not be a marketplace. When the
autofeed is enabled for the first time, the products usually appear instantly.
When re-enabling, it might take up to 24 hours for products to appear.
Corresponds to the JSON property enableProducts
624 625 626 |
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 624 def enable_products @enable_products end |
#name ⇒ String
Identifier. The resource name of the autofeed settings. Format: accounts/
account/autofeedSettings.
Corresponds to the JSON property name
631 632 633 |
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 631 def name @name end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
638 639 640 641 642 |
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 638 def update!(**args) @eligible = args[:eligible] if args.key?(:eligible) @enable_products = args[:enable_products] if args.key?(:enable_products) @name = args[:name] if args.key?(:name) end |