Class: Google::Apis::MerchantapiAccountsV1beta::AutofeedSettings

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/merchantapi_accounts_v1beta/classes.rb,
lib/google/apis/merchantapi_accounts_v1beta/representations.rb,
lib/google/apis/merchantapi_accounts_v1beta/representations.rb

Overview

Collection of information related to the autofeed settings.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ AutofeedSettings

Returns a new instance of AutofeedSettings.



627
628
629
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 627

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#eligibleBoolean Also known as: eligible?

Output only. Determines whether the business is eligible for being enrolled into an autofeed. Corresponds to the JSON property eligible

Returns:

  • (Boolean)


606
607
608
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 606

def eligible
  @eligible
end

#enable_productsBoolean Also known as: enable_products?

Required. Enables or disables product crawling through the autofeed for the given account. Autofeed accounts must meet certain conditions, which can be checked through the eligible field. The account must not be a marketplace. When the autofeed is enabled for the first time, the products usually appear instantly. When re-enabling, it might take up to 24 hours for products to appear. Corresponds to the JSON property enableProducts

Returns:

  • (Boolean)


618
619
620
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 618

def enable_products
  @enable_products
end

#nameString

Identifier. The resource name of the autofeed settings. Format: accounts/ account/autofeedSettings. Corresponds to the JSON property name

Returns:

  • (String)


625
626
627
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 625

def name
  @name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



632
633
634
635
636
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 632

def update!(**args)
  @eligible = args[:eligible] if args.key?(:eligible)
  @enable_products = args[:enable_products] if args.key?(:enable_products)
  @name = args[:name] if args.key?(:name)
end