Class: Google::Apis::MerchantapiAccountsV1beta::AutomaticImageImprovements

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/merchantapi_accounts_v1beta/classes.rb,
lib/google/apis/merchantapi_accounts_v1beta/representations.rb,
lib/google/apis/merchantapi_accounts_v1beta/representations.rb

Overview

This improvement will attempt to automatically correct submitted images if they don't meet the image requirements, for example, removing overlays. If successful, the image will be replaced and approved. This improvement is only applied to images of disapproved offers. For more information see: Automatic image improvements

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ AutomaticImageImprovements

Returns a new instance of AutomaticImageImprovements.



661
662
663
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 661

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#account_image_improvements_settingsGoogle::Apis::MerchantapiAccountsV1beta::ImageImprovementsAccountLevelSettings

Settings for the Automatic Image Improvements. Corresponds to the JSON property accountImageImprovementsSettings



651
652
653
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 651

def 
  @account_image_improvements_settings
end

#effective_allow_automatic_image_improvementsBoolean Also known as: effective_allow_automatic_image_improvements?

Output only. The effective value of allow_automatic_image_improvements. If account_image_improvements_settings is present, then this value is the same. Otherwise, it represents the inherited value of the parent account. Read-only. Corresponds to the JSON property effectiveAllowAutomaticImageImprovements

Returns:

  • (Boolean)


658
659
660
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 658

def effective_allow_automatic_image_improvements
  @effective_allow_automatic_image_improvements
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



666
667
668
669
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 666

def update!(**args)
  @account_image_improvements_settings = args[:account_image_improvements_settings] if args.key?(:account_image_improvements_settings)
  @effective_allow_automatic_image_improvements = args[:effective_allow_automatic_image_improvements] if args.key?(:effective_allow_automatic_image_improvements)
end