Class: Google::Apis::MerchantapiAccountsV1beta::AutomaticItemUpdates
- Inherits:
-
Object
- Object
- Google::Apis::MerchantapiAccountsV1beta::AutomaticItemUpdates
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/merchantapi_accounts_v1beta/classes.rb,
lib/google/apis/merchantapi_accounts_v1beta/representations.rb,
lib/google/apis/merchantapi_accounts_v1beta/representations.rb
Overview
Turning on item updates allows Google to automatically update items for you. When item updates are on, Google uses the structured data markup on the website and advanced data extractors to update the price and availability of the items. When the item updates are off, items with mismatched data aren't shown.
Instance Attribute Summary collapse
-
#account_item_updates_settings ⇒ Google::Apis::MerchantapiAccountsV1beta::ItemUpdatesAccountLevelSettings
Settings for the Automatic Item Updates.
-
#effective_allow_availability_updates ⇒ Boolean
(also: #effective_allow_availability_updates?)
Output only.
-
#effective_allow_condition_updates ⇒ Boolean
(also: #effective_allow_condition_updates?)
Output only.
-
#effective_allow_price_updates ⇒ Boolean
(also: #effective_allow_price_updates?)
Output only.
-
#effective_allow_strict_availability_updates ⇒ Boolean
(also: #effective_allow_strict_availability_updates?)
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ AutomaticItemUpdates
constructor
A new instance of AutomaticItemUpdates.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ AutomaticItemUpdates
Returns a new instance of AutomaticItemUpdates.
784 785 786 |
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 784 def initialize(**args) update!(**args) end |
Instance Attribute Details
#account_item_updates_settings ⇒ Google::Apis::MerchantapiAccountsV1beta::ItemUpdatesAccountLevelSettings
Settings for the Automatic Item Updates.
Corresponds to the JSON property accountItemUpdatesSettings
746 747 748 |
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 746 def account_item_updates_settings @account_item_updates_settings end |
#effective_allow_availability_updates ⇒ Boolean Also known as: effective_allow_availability_updates?
Output only. The effective value of allow_availability_updates. If
account_item_updates_settings is present, then this value is the same.
Otherwise, it represents the inherited value of the parent account. The
default value is true if no settings are present. Read-only.
Corresponds to the JSON property effectiveAllowAvailabilityUpdates
754 755 756 |
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 754 def effective_allow_availability_updates @effective_allow_availability_updates end |
#effective_allow_condition_updates ⇒ Boolean Also known as: effective_allow_condition_updates?
Output only. The effective value of allow_condition_updates. If
account_item_updates_settings is present, then this value is the same.
Otherwise, it represents the inherited value of the parent account. The
default value is true if no settings are present. Read-only.
Corresponds to the JSON property effectiveAllowConditionUpdates
763 764 765 |
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 763 def effective_allow_condition_updates @effective_allow_condition_updates end |
#effective_allow_price_updates ⇒ Boolean Also known as: effective_allow_price_updates?
Output only. The effective value of allow_price_updates. If
account_item_updates_settings is present, then this value is the same.
Otherwise, it represents the inherited value of the parent account. The
default value is true if no settings are present. Read-only.
Corresponds to the JSON property effectiveAllowPriceUpdates
772 773 774 |
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 772 def effective_allow_price_updates @effective_allow_price_updates end |
#effective_allow_strict_availability_updates ⇒ Boolean Also known as: effective_allow_strict_availability_updates?
Output only. The effective value of allow_strict_availability_updates. If
account_item_updates_settings is present, then this value is the same.
Otherwise, it represents the inherited value of the parent account. The
default value is true if no settings are present. Read-only.
Corresponds to the JSON property effectiveAllowStrictAvailabilityUpdates
781 782 783 |
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 781 def effective_allow_strict_availability_updates @effective_allow_strict_availability_updates end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
789 790 791 792 793 794 795 |
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 789 def update!(**args) @account_item_updates_settings = args[:account_item_updates_settings] if args.key?(:account_item_updates_settings) @effective_allow_availability_updates = args[:effective_allow_availability_updates] if args.key?(:effective_allow_availability_updates) @effective_allow_condition_updates = args[:effective_allow_condition_updates] if args.key?(:effective_allow_condition_updates) @effective_allow_price_updates = args[:effective_allow_price_updates] if args.key?(:effective_allow_price_updates) @effective_allow_strict_availability_updates = args[:effective_allow_strict_availability_updates] if args.key?(:effective_allow_strict_availability_updates) end |