Class: Google::Apis::MerchantapiAccountsV1beta::AutomaticItemUpdates
- Inherits:
-
Object
- Object
- Google::Apis::MerchantapiAccountsV1beta::AutomaticItemUpdates
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/merchantapi_accounts_v1beta/classes.rb,
lib/google/apis/merchantapi_accounts_v1beta/representations.rb,
lib/google/apis/merchantapi_accounts_v1beta/representations.rb
Overview
Turning on item updates allows Google to automatically update items for you. When item updates are on, Google uses the structured data markup on the website and advanced data extractors to update the price and availability of the items. When the item updates are off, items with mismatched data aren't shown.
Instance Attribute Summary collapse
-
#account_item_updates_settings ⇒ Google::Apis::MerchantapiAccountsV1beta::ItemUpdatesAccountLevelSettings
Settings for the Automatic Item Updates.
-
#effective_allow_availability_updates ⇒ Boolean
(also: #effective_allow_availability_updates?)
Output only.
-
#effective_allow_condition_updates ⇒ Boolean
(also: #effective_allow_condition_updates?)
Output only.
-
#effective_allow_price_updates ⇒ Boolean
(also: #effective_allow_price_updates?)
Output only.
-
#effective_allow_strict_availability_updates ⇒ Boolean
(also: #effective_allow_strict_availability_updates?)
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ AutomaticItemUpdates
constructor
A new instance of AutomaticItemUpdates.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ AutomaticItemUpdates
Returns a new instance of AutomaticItemUpdates.
778 779 780 |
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 778 def initialize(**args) update!(**args) end |
Instance Attribute Details
#account_item_updates_settings ⇒ Google::Apis::MerchantapiAccountsV1beta::ItemUpdatesAccountLevelSettings
Settings for the Automatic Item Updates.
Corresponds to the JSON property accountItemUpdatesSettings
740 741 742 |
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 740 def account_item_updates_settings @account_item_updates_settings end |
#effective_allow_availability_updates ⇒ Boolean Also known as: effective_allow_availability_updates?
Output only. The effective value of allow_availability_updates. If
account_item_updates_settings is present, then this value is the same.
Otherwise, it represents the inherited value of the parent account. The
default value is true if no settings are present. Read-only.
Corresponds to the JSON property effectiveAllowAvailabilityUpdates
748 749 750 |
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 748 def effective_allow_availability_updates @effective_allow_availability_updates end |
#effective_allow_condition_updates ⇒ Boolean Also known as: effective_allow_condition_updates?
Output only. The effective value of allow_condition_updates. If
account_item_updates_settings is present, then this value is the same.
Otherwise, it represents the inherited value of the parent account. The
default value is true if no settings are present. Read-only.
Corresponds to the JSON property effectiveAllowConditionUpdates
757 758 759 |
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 757 def effective_allow_condition_updates @effective_allow_condition_updates end |
#effective_allow_price_updates ⇒ Boolean Also known as: effective_allow_price_updates?
Output only. The effective value of allow_price_updates. If
account_item_updates_settings is present, then this value is the same.
Otherwise, it represents the inherited value of the parent account. The
default value is true if no settings are present. Read-only.
Corresponds to the JSON property effectiveAllowPriceUpdates
766 767 768 |
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 766 def effective_allow_price_updates @effective_allow_price_updates end |
#effective_allow_strict_availability_updates ⇒ Boolean Also known as: effective_allow_strict_availability_updates?
Output only. The effective value of allow_strict_availability_updates. If
account_item_updates_settings is present, then this value is the same.
Otherwise, it represents the inherited value of the parent account. The
default value is true if no settings are present. Read-only.
Corresponds to the JSON property effectiveAllowStrictAvailabilityUpdates
775 776 777 |
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 775 def effective_allow_strict_availability_updates @effective_allow_strict_availability_updates end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
783 784 785 786 787 788 789 |
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 783 def update!(**args) @account_item_updates_settings = args[:account_item_updates_settings] if args.key?(:account_item_updates_settings) @effective_allow_availability_updates = args[:effective_allow_availability_updates] if args.key?(:effective_allow_availability_updates) @effective_allow_condition_updates = args[:effective_allow_condition_updates] if args.key?(:effective_allow_condition_updates) @effective_allow_price_updates = args[:effective_allow_price_updates] if args.key?(:effective_allow_price_updates) @effective_allow_strict_availability_updates = args[:effective_allow_strict_availability_updates] if args.key?(:effective_allow_strict_availability_updates) end |