Class: Google::Apis::MerchantapiAccountsV1beta::AutomaticShippingImprovements
- Inherits:
-
Object
- Object
- Google::Apis::MerchantapiAccountsV1beta::AutomaticShippingImprovements
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/merchantapi_accounts_v1beta/classes.rb,
lib/google/apis/merchantapi_accounts_v1beta/representations.rb,
lib/google/apis/merchantapi_accounts_v1beta/representations.rb
Overview
Not available for advanced accounts. By turning on automatic shipping improvements, you are allowing Google to improve the accuracy of your delivery times shown to shoppers using Google. More accurate delivery times, especially when faster, typically lead to better conversion rates. Google will improve your estimated delivery times based on various factors: * Delivery address of an order * Current handling time and shipping time settings * Estimated weekdays or business days * Parcel tracking data
Instance Attribute Summary collapse
-
#allow_shipping_improvements ⇒ Boolean
(also: #allow_shipping_improvements?)
Enables automatic shipping improvements.
Instance Method Summary collapse
-
#initialize(**args) ⇒ AutomaticShippingImprovements
constructor
A new instance of AutomaticShippingImprovements.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ AutomaticShippingImprovements
Returns a new instance of AutomaticShippingImprovements.
810 811 812 |
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 810 def initialize(**args) update!(**args) end |
Instance Attribute Details
#allow_shipping_improvements ⇒ Boolean Also known as: allow_shipping_improvements?
Enables automatic shipping improvements.
Corresponds to the JSON property allowShippingImprovements
807 808 809 |
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 807 def allow_shipping_improvements @allow_shipping_improvements end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
815 816 817 |
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 815 def update!(**args) @allow_shipping_improvements = args[:allow_shipping_improvements] if args.key?(:allow_shipping_improvements) end |