Class: Google::Apis::MerchantapiAccountsV1beta::BusinessInfo
- Inherits:
-
Object
- Object
- Google::Apis::MerchantapiAccountsV1beta::BusinessInfo
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/merchantapi_accounts_v1beta/classes.rb,
lib/google/apis/merchantapi_accounts_v1beta/representations.rb,
lib/google/apis/merchantapi_accounts_v1beta/representations.rb
Overview
The BusinessInfo message contains essential information about a business.
This message captures key business details such as physical address, customer
service contacts, and region-specific identifiers.
Instance Attribute Summary collapse
-
#address ⇒ Google::Apis::MerchantapiAccountsV1beta::PostalAddress
Represents a postal address, such as for postal delivery or payments addresses.
-
#customer_service ⇒ Google::Apis::MerchantapiAccountsV1beta::CustomerService
Customer service information.
-
#korean_business_registration_number ⇒ String
Optional.
-
#name ⇒ String
Identifier.
-
#phone ⇒ Google::Apis::MerchantapiAccountsV1beta::PhoneNumber
An object representing a phone number, suitable as an API wire format.
-
#phone_verification_state ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ BusinessInfo
constructor
A new instance of BusinessInfo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ BusinessInfo
Returns a new instance of BusinessInfo.
963 964 965 |
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 963 def initialize(**args) update!(**args) end |
Instance Attribute Details
#address ⇒ Google::Apis::MerchantapiAccountsV1beta::PostalAddress
Represents a postal address, such as for postal delivery or payments addresses.
With a postal address, a postal service can deliver items to a premise, P.O.
box, or similar. A postal address is not intended to model geographical
locations like roads, towns, or mountains. In typical usage, an address would
be created by user input or from importing existing data, depending on the
type of process. Advice on address input or editing: - Use an
internationalization-ready address widget such as https://github.com/google/
libaddressinput. - Users should not be presented with UI elements for input or
editing of fields outside countries where that field is used. For more
guidance on how to use this schema, see: https://support.google.com/business/
answer/6397478.
Corresponds to the JSON property address
921 922 923 |
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 921 def address @address end |
#customer_service ⇒ Google::Apis::MerchantapiAccountsV1beta::CustomerService
Customer service information.
Corresponds to the JSON property customerService
926 927 928 |
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 926 def customer_service @customer_service end |
#korean_business_registration_number ⇒ String
Optional. The 10-digit Korean business registration number separated with dashes in the format: XXX-
XX-XXXXX.
Corresponds to the JSON property koreanBusinessRegistrationNumber
933 934 935 |
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 933 def korean_business_registration_number @korean_business_registration_number end |
#name ⇒ String
Identifier. The resource name of the business info. Format: accounts/account
/businessInfo
Corresponds to the JSON property name
939 940 941 |
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 939 def name @name end |
#phone ⇒ Google::Apis::MerchantapiAccountsV1beta::PhoneNumber
An object representing a phone number, suitable as an API wire format. This
representation: - should not be used for locale-specific formatting of a phone
number, such as "+1 (650) 253-0000 ext. 123" - is not designed for efficient
storage - may not be suitable for dialing - specialized libraries (see
references) should be used to parse the number for that purpose To do
something meaningful with this number, such as format it for various use-cases,
convert it to an i18n.phonenumbers.PhoneNumber object first. For instance,
in Java this would be: com.google.type.PhoneNumber wireProto = com.google.type.
PhoneNumber.newBuilder().build(); com.google.i18n.phonenumbers.Phonenumber.
PhoneNumber phoneNumber = PhoneNumberUtil.getInstance().parse(wireProto.
getE164Number(), "ZZ"); if (!wireProto.getExtension().isEmpty()) phoneNumber.
setExtension(wireProto.getExtension()); Reference(s): - https://github.com/
google/libphonenumber
Corresponds to the JSON property phone
956 957 958 |
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 956 def phone @phone end |
#phone_verification_state ⇒ String
Output only. The phone verification state of the business.
Corresponds to the JSON property phoneVerificationState
961 962 963 |
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 961 def phone_verification_state @phone_verification_state end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
968 969 970 971 972 973 974 975 |
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 968 def update!(**args) @address = args[:address] if args.key?(:address) @customer_service = args[:customer_service] if args.key?(:customer_service) @korean_business_registration_number = args[:korean_business_registration_number] if args.key?(:korean_business_registration_number) @name = args[:name] if args.key?(:name) @phone = args[:phone] if args.key?(:phone) @phone_verification_state = args[:phone_verification_state] if args.key?(:phone_verification_state) end |