Class: Google::Apis::MerchantapiAccountsV1beta::ClaimHomepageRequest
- Inherits:
-
Object
- Object
- Google::Apis::MerchantapiAccountsV1beta::ClaimHomepageRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/merchantapi_accounts_v1beta/classes.rb,
lib/google/apis/merchantapi_accounts_v1beta/representations.rb,
lib/google/apis/merchantapi_accounts_v1beta/representations.rb
Overview
Request message for the ClaimHomepage method.
Instance Attribute Summary collapse
-
#overwrite ⇒ Boolean
(also: #overwrite?)
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ClaimHomepageRequest
constructor
A new instance of ClaimHomepageRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ClaimHomepageRequest
Returns a new instance of ClaimHomepageRequest.
1129 1130 1131 |
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 1129 def initialize(**args) update!(**args) end |
Instance Attribute Details
#overwrite ⇒ Boolean Also known as: overwrite?
Optional. When set to true, this option removes any existing claim on the
requested website from any other account to the account making the request,
effectively replacing the previous claim.
Corresponds to the JSON property overwrite
1126 1127 1128 |
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 1126 def overwrite @overwrite end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1134 1135 1136 |
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 1134 def update!(**args) @overwrite = args[:overwrite] if args.key?(:overwrite) end |