Class: Google::Apis::MerchantapiAccountsV1beta::CreateAndConfigureAccountRequest
- Inherits:
-
Object
- Object
- Google::Apis::MerchantapiAccountsV1beta::CreateAndConfigureAccountRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/merchantapi_accounts_v1beta/classes.rb,
lib/google/apis/merchantapi_accounts_v1beta/representations.rb,
lib/google/apis/merchantapi_accounts_v1beta/representations.rb
Overview
Request message for the CreateAndConfigureAccount method.
Instance Attribute Summary collapse
-
#account ⇒ Google::Apis::MerchantapiAccountsV1beta::Account
The
Accountmessage represents a business's account within Merchant Center. -
#service ⇒ Array<Google::Apis::MerchantapiAccountsV1beta::AddAccountService>
Required.
-
#set_alias ⇒ Array<Google::Apis::MerchantapiAccountsV1beta::SetAliasForRelationship>
Optional.
-
#user ⇒ Array<Google::Apis::MerchantapiAccountsV1beta::AddUser>
Optional.
-
#users ⇒ Array<Google::Apis::MerchantapiAccountsV1beta::CreateUserRequest>
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ CreateAndConfigureAccountRequest
constructor
A new instance of CreateAndConfigureAccountRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ CreateAndConfigureAccountRequest
Returns a new instance of CreateAndConfigureAccountRequest.
1198 1199 1200 |
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 1198 def initialize(**args) update!(**args) end |
Instance Attribute Details
#account ⇒ Google::Apis::MerchantapiAccountsV1beta::Account
The Account message represents a business's account within Merchant Center.
It's the primary entity for managing product data, settings, and interactions
with Google's services and external providers. Accounts can operate as
standalone entities or be part of a advanced account structure. In an advanced
account setup the parent account manages multiple sub-accounts. Establishing
an account involves configuring attributes like the account name, time zone,
and language preferences. The Account message is the parent entity for many
other resources, for example, AccountRelationship, Homepage, BusinessInfo
and so on.
Corresponds to the JSON property account
1167 1168 1169 |
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 1167 def account @account end |
#service ⇒ Array<Google::Apis::MerchantapiAccountsV1beta::AddAccountService>
Required. An account service between the account to be created and the
provider account is initialized as part of the creation. At least one such
service needs to be provided. Currently exactly one of these needs to be
account_aggregation and accounts.createAndConfigure method can be used to
create a sub-account under an existing advanced account through this method.
Additional account_management or products_management services may be
provided.
Corresponds to the JSON property service
1178 1179 1180 |
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 1178 def service @service end |
#set_alias ⇒ Array<Google::Apis::MerchantapiAccountsV1beta::SetAliasForRelationship>
Optional. If a relationship is created with a provider, you can set an alias
for it with this field. The calling user must be an admin on the provider to
be able to set an alias.
Corresponds to the JSON property setAlias
1185 1186 1187 |
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 1185 def set_alias @set_alias end |
#user ⇒ Array<Google::Apis::MerchantapiAccountsV1beta::AddUser>
Optional. Users to be added to the account.
Corresponds to the JSON property user
1190 1191 1192 |
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 1190 def user @user end |
#users ⇒ Array<Google::Apis::MerchantapiAccountsV1beta::CreateUserRequest>
Optional. Users to be added to the account. This field is deprecated and will
not exist after the API evolves out of beta. Use the user field instead.
Corresponds to the JSON property users
1196 1197 1198 |
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 1196 def users @users end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1203 1204 1205 1206 1207 1208 1209 |
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 1203 def update!(**args) @account = args[:account] if args.key?(:account) @service = args[:service] if args.key?(:service) @set_alias = args[:set_alias] if args.key?(:set_alias) @user = args[:user] if args.key?(:user) @users = args[:users] if args.key?(:users) end |