Class: Google::Apis::MerchantapiAccountsV1beta::CreateUserRequest
- Inherits:
-
Object
- Object
- Google::Apis::MerchantapiAccountsV1beta::CreateUserRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/merchantapi_accounts_v1beta/classes.rb,
lib/google/apis/merchantapi_accounts_v1beta/representations.rb,
lib/google/apis/merchantapi_accounts_v1beta/representations.rb
Overview
Request message for the CreateUser method.
Instance Attribute Summary collapse
-
#parent ⇒ String
Required.
-
#user ⇒ Google::Apis::MerchantapiAccountsV1beta::User
The
Userresource represents a user associated with a Merchant Center account. -
#user_id ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ CreateUserRequest
constructor
A new instance of CreateUserRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ CreateUserRequest
Returns a new instance of CreateUserRequest.
1241 1242 1243 |
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 1241 def initialize(**args) update!(**args) end |
Instance Attribute Details
#parent ⇒ String
Required. The resource name of the account for which a user will be created.
Format: accounts/account`
Corresponds to the JSON propertyparent`
1226 1227 1228 |
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 1226 def parent @parent end |
#user ⇒ Google::Apis::MerchantapiAccountsV1beta::User
The User resource represents a user associated with a Merchant Center
account. It is used to manage user permissions and access rights within the
account. For more information, see Frequently asked questions about people
and access levels.
Corresponds to the JSON property user
1234 1235 1236 |
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 1234 def user @user end |
#user_id ⇒ String
Required. The email address of the user (for example, john.doe@gmail.com).
Corresponds to the JSON property userId
1239 1240 1241 |
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 1239 def user_id @user_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1246 1247 1248 1249 1250 |
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 1246 def update!(**args) @parent = args[:parent] if args.key?(:parent) @user = args[:user] if args.key?(:user) @user_id = args[:user_id] if args.key?(:user_id) end |