Class: Google::Apis::MerchantapiAccountsV1beta::CutoffTime
- Inherits:
-
Object
- Object
- Google::Apis::MerchantapiAccountsV1beta::CutoffTime
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/merchantapi_accounts_v1beta/classes.rb,
lib/google/apis/merchantapi_accounts_v1beta/representations.rb,
lib/google/apis/merchantapi_accounts_v1beta/representations.rb
Overview
Business days cutoff time definition.
Instance Attribute Summary collapse
-
#hour ⇒ Fixnum
Required.
-
#minute ⇒ Fixnum
Required.
-
#time_zone ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ CutoffTime
constructor
A new instance of CutoffTime.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ CutoffTime
Returns a new instance of CutoffTime.
1352 1353 1354 |
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 1352 def initialize(**args) update!(**args) end |
Instance Attribute Details
#hour ⇒ Fixnum
Required. Hour of the cutoff time until which an order has to be placed to be
processed in the same day.
Corresponds to the JSON property hour
1338 1339 1340 |
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 1338 def hour @hour end |
#minute ⇒ Fixnum
Required. Minute of the cutoff time until which an order has to be placed to
be processed in the same day.
Corresponds to the JSON property minute
1344 1345 1346 |
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 1344 def minute @minute end |
#time_zone ⇒ String
Required. Timezone identifier For example "Europe/Zurich".
Corresponds to the JSON property timeZone
1350 1351 1352 |
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 1350 def time_zone @time_zone end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1357 1358 1359 1360 1361 |
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 1357 def update!(**args) @hour = args[:hour] if args.key?(:hour) @minute = args[:minute] if args.key?(:minute) @time_zone = args[:time_zone] if args.key?(:time_zone) end |