Class: Google::Apis::MerchantapiAccountsV1beta::DeveloperRegistration

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/merchantapi_accounts_v1beta/classes.rb,
lib/google/apis/merchantapi_accounts_v1beta/representations.rb,
lib/google/apis/merchantapi_accounts_v1beta/representations.rb

Overview

Represents a developer registration owned by a Merchant account.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ DeveloperRegistration

Returns a new instance of DeveloperRegistration.



1501
1502
1503
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 1501

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#gcp_idsArray<String>

Output only. The GCP ids attached to this developer registration Corresponds to the JSON property gcpIds

Returns:

  • (Array<String>)


1492
1493
1494
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 1492

def gcp_ids
  @gcp_ids
end

#nameString

Identifier. The name (ID) of the developer registration. Generated upon creation of a new DeveloperRegistration. The account represents the merchant ID of the merchant that owns the registration. Corresponds to the JSON property name

Returns:

  • (String)


1499
1500
1501
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 1499

def name
  @name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1506
1507
1508
1509
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 1506

def update!(**args)
  @gcp_ids = args[:gcp_ids] if args.key?(:gcp_ids)
  @name = args[:name] if args.key?(:name)
end