Class: Google::Apis::MerchantapiAccountsV1beta::Distance
- Inherits:
-
Object
- Object
- Google::Apis::MerchantapiAccountsV1beta::Distance
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/merchantapi_accounts_v1beta/classes.rb,
lib/google/apis/merchantapi_accounts_v1beta/representations.rb,
lib/google/apis/merchantapi_accounts_v1beta/representations.rb
Overview
Maximum delivery radius. This is only required for the local delivery shipment type.
Instance Attribute Summary collapse
-
#unit ⇒ String
Unit can differ based on country, it is parameterized to include miles and kilometers.
-
#value ⇒ Fixnum
Integer value of distance.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Distance
constructor
A new instance of Distance.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Distance
Returns a new instance of Distance.
1547 1548 1549 |
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 1547 def initialize(**args) update!(**args) end |
Instance Attribute Details
#unit ⇒ String
Unit can differ based on country, it is parameterized to include miles and
kilometers.
Corresponds to the JSON property unit
1540 1541 1542 |
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 1540 def unit @unit end |
#value ⇒ Fixnum
Integer value of distance.
Corresponds to the JSON property value
1545 1546 1547 |
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 1545 def value @value end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1552 1553 1554 1555 |
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 1552 def update!(**args) @unit = args[:unit] if args.key?(:unit) @value = args[:value] if args.key?(:value) end |