Class: Google::Apis::MerchantapiAccountsV1beta::Homepage

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/merchantapi_accounts_v1beta/classes.rb,
lib/google/apis/merchantapi_accounts_v1beta/representations.rb,
lib/google/apis/merchantapi_accounts_v1beta/representations.rb

Overview

The Homepage message represents a business's store homepage within the system. A business's homepage is the primary domain where customers interact with their store. The homepage can be claimed and verified as a proof of ownership and allows the business to unlock features that require a verified website. For more information, see Understanding online store URL verification.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Homepage

Returns a new instance of Homepage.



1837
1838
1839
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 1837

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#claimedBoolean Also known as: claimed?

Output only. Whether the homepage is claimed. See https://support.google.com/ merchants/answer/176793. Corresponds to the JSON property claimed

Returns:

  • (Boolean)


1823
1824
1825
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 1823

def claimed
  @claimed
end

#nameString

Identifier. The resource name of the store's homepage. Format: accounts/ account/homepage Corresponds to the JSON property name

Returns:

  • (String)


1830
1831
1832
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 1830

def name
  @name
end

#uriString

Required. The URI (typically a URL) of the store's homepage. Corresponds to the JSON property uri

Returns:

  • (String)


1835
1836
1837
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 1835

def uri
  @uri
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1842
1843
1844
1845
1846
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 1842

def update!(**args)
  @claimed = args[:claimed] if args.key?(:claimed)
  @name = args[:name] if args.key?(:name)
  @uri = args[:uri] if args.key?(:uri)
end