Class: Google::Apis::MerchantapiAccountsV1beta::InventoryVerification

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/merchantapi_accounts_v1beta/classes.rb,
lib/google/apis/merchantapi_accounts_v1beta/representations.rb,
lib/google/apis/merchantapi_accounts_v1beta/representations.rb

Overview

Collection of information related to inventory verification.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InventoryVerification

Returns a new instance of InventoryVerification.



1993
1994
1995
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 1993

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#contactString

Required. The name of the contact for the inventory verification process. Corresponds to the JSON property contact

Returns:

  • (String)


1975
1976
1977
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 1975

def contact
  @contact
end

#contact_emailString

Required. The email address of the contact for the inventory verification process. Corresponds to the JSON property contactEmail

Returns:

  • (String)


1981
1982
1983
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 1981

def contact_email
  @contact_email
end

#contact_stateString

Output only. The state of the contact verification. Corresponds to the JSON property contactState

Returns:

  • (String)


1986
1987
1988
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 1986

def contact_state
  @contact_state
end

#stateString

Output only. The state of the inventory verification process. Corresponds to the JSON property state

Returns:

  • (String)


1991
1992
1993
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 1991

def state
  @state
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1998
1999
2000
2001
2002
2003
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 1998

def update!(**args)
  @contact = args[:contact] if args.key?(:contact)
  @contact_email = args[:contact_email] if args.key?(:contact_email)
  @contact_state = args[:contact_state] if args.key?(:contact_state)
  @state = args[:state] if args.key?(:state)
end