Class: Google::Apis::MerchantapiAccountsV1beta::LatLng
- Inherits:
-
Object
- Object
- Google::Apis::MerchantapiAccountsV1beta::LatLng
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/merchantapi_accounts_v1beta/classes.rb,
lib/google/apis/merchantapi_accounts_v1beta/representations.rb,
lib/google/apis/merchantapi_accounts_v1beta/representations.rb
Overview
An object that represents a latitude/longitude pair. This is expressed as a pair of doubles to represent degrees latitude and degrees longitude. Unless specified otherwise, this object must conform to the WGS84 standard. Values must be within normalized ranges.
Instance Attribute Summary collapse
-
#latitude ⇒ Float
The latitude in degrees.
-
#longitude ⇒ Float
The longitude in degrees.
Instance Method Summary collapse
-
#initialize(**args) ⇒ LatLng
constructor
A new instance of LatLng.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ LatLng
Returns a new instance of LatLng.
2074 2075 2076 |
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 2074 def initialize(**args) update!(**args) end |
Instance Attribute Details
#latitude ⇒ Float
The latitude in degrees. It must be in the range [-90.0, +90.0].
Corresponds to the JSON property latitude
2067 2068 2069 |
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 2067 def latitude @latitude end |
#longitude ⇒ Float
The longitude in degrees. It must be in the range [-180.0, +180.0].
Corresponds to the JSON property longitude
2072 2073 2074 |
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 2072 def longitude @longitude end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2079 2080 2081 2082 |
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 2079 def update!(**args) @latitude = args[:latitude] if args.key?(:latitude) @longitude = args[:longitude] if args.key?(:longitude) end |