Class: Google::Apis::MerchantapiAccountsV1beta::LinkGbpAccountResponse
- Inherits:
-
Object
- Object
- Google::Apis::MerchantapiAccountsV1beta::LinkGbpAccountResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/merchantapi_accounts_v1beta/classes.rb,
lib/google/apis/merchantapi_accounts_v1beta/representations.rb,
lib/google/apis/merchantapi_accounts_v1beta/representations.rb
Overview
Response message for the LinkGbpAccount method.
Instance Attribute Summary collapse
-
#response ⇒ Google::Apis::MerchantapiAccountsV1beta::Empty
A generic empty message that you can re-use to avoid defining duplicated empty messages in your APIs.
Instance Method Summary collapse
-
#initialize(**args) ⇒ LinkGbpAccountResponse
constructor
A new instance of LinkGbpAccountResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ LinkGbpAccountResponse
Returns a new instance of LinkGbpAccountResponse.
2180 2181 2182 |
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 2180 def initialize(**args) update!(**args) end |
Instance Attribute Details
#response ⇒ Google::Apis::MerchantapiAccountsV1beta::Empty
A generic empty message that you can re-use to avoid defining duplicated empty
messages in your APIs. A typical example is to use it as the request or the
response type of an API method. For instance: service Foo rpc Bar(google.
protobuf.Empty) returns (google.protobuf.Empty);
Corresponds to the JSON property response
2178 2179 2180 |
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 2178 def response @response end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2185 2186 2187 |
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 2185 def update!(**args) @response = args[:response] if args.key?(:response) end |