Class: Google::Apis::MerchantapiAccountsV1beta::LocalCutoffTime

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/merchantapi_accounts_v1beta/classes.rb,
lib/google/apis/merchantapi_accounts_v1beta/representations.rb,
lib/google/apis/merchantapi_accounts_v1beta/representations.rb

Overview

Time that local delivery ends for the day.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ LocalCutoffTime

Returns a new instance of LocalCutoffTime.



2532
2533
2534
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 2532

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#hourFixnum

Hour local delivery orders must be placed by to process the same day. Corresponds to the JSON property hour

Returns:

  • (Fixnum)


2525
2526
2527
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 2525

def hour
  @hour
end

#minuteFixnum

Minute local delivery orders must be placed by to process the same day. Corresponds to the JSON property minute

Returns:

  • (Fixnum)


2530
2531
2532
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 2530

def minute
  @minute
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2537
2538
2539
2540
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 2537

def update!(**args)
  @hour = args[:hour] if args.key?(:hour)
  @minute = args[:minute] if args.key?(:minute)
end