Class: Google::Apis::MerchantapiAccountsV1beta::LoyaltyProgram
- Inherits:
-
Object
- Object
- Google::Apis::MerchantapiAccountsV1beta::LoyaltyProgram
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/merchantapi_accounts_v1beta/classes.rb,
lib/google/apis/merchantapi_accounts_v1beta/representations.rb,
lib/google/apis/merchantapi_accounts_v1beta/representations.rb
Overview
Loyalty program provided by a business.
Instance Attribute Summary collapse
-
#loyalty_program_tiers ⇒ Array<Google::Apis::MerchantapiAccountsV1beta::LoyaltyProgramTiers>
Optional.
-
#program_label ⇒ String
This is the loyalty program label set in your loyalty program settings in Merchant Center.
Instance Method Summary collapse
-
#initialize(**args) ⇒ LoyaltyProgram
constructor
A new instance of LoyaltyProgram.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ LoyaltyProgram
Returns a new instance of LoyaltyProgram.
2595 2596 2597 |
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 2595 def initialize(**args) update!(**args) end |
Instance Attribute Details
#loyalty_program_tiers ⇒ Array<Google::Apis::MerchantapiAccountsV1beta::LoyaltyProgramTiers>
Optional. Loyalty program tier of this shipping service.
Corresponds to the JSON property loyaltyProgramTiers
2586 2587 2588 |
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 2586 def loyalty_program_tiers @loyalty_program_tiers end |
#program_label ⇒ String
This is the loyalty program label set in your loyalty program settings in
Merchant Center. This sub-attribute allows Google to map your loyalty program
to eligible offers.
Corresponds to the JSON property programLabel
2593 2594 2595 |
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 2593 def program_label @program_label end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2600 2601 2602 2603 |
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 2600 def update!(**args) @loyalty_program_tiers = args[:loyalty_program_tiers] if args.key?(:loyalty_program_tiers) @program_label = args[:program_label] if args.key?(:program_label) end |