Class: Google::Apis::MerchantapiAccountsV1beta::LoyaltyProgramTiers
- Inherits:
-
Object
- Object
- Google::Apis::MerchantapiAccountsV1beta::LoyaltyProgramTiers
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/merchantapi_accounts_v1beta/classes.rb,
lib/google/apis/merchantapi_accounts_v1beta/representations.rb,
lib/google/apis/merchantapi_accounts_v1beta/representations.rb
Overview
Subset of a business's loyalty program.
Instance Attribute Summary collapse
-
#tier_label ⇒ String
The tier label [tier_label] sub-attribute differentiates offer level benefits between each tier.
Instance Method Summary collapse
-
#initialize(**args) ⇒ LoyaltyProgramTiers
constructor
A new instance of LoyaltyProgramTiers.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ LoyaltyProgramTiers
Returns a new instance of LoyaltyProgramTiers.
2624 2625 2626 |
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 2624 def initialize(**args) update!(**args) end |
Instance Attribute Details
#tier_label ⇒ String
The tier label [tier_label] sub-attribute differentiates offer level benefits
between each tier. This value is also set in your program settings in Merchant
Center, and is required for data source changes even if your loyalty program
only has 1 tier.
Corresponds to the JSON property tierLabel
2622 2623 2624 |
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 2622 def tier_label @tier_label end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2629 2630 2631 |
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 2629 def update!(**args) @tier_label = args[:tier_label] if args.key?(:tier_label) end |