Class: Google::Apis::MerchantapiAccountsV1beta::MinimumOrderValueTable

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/merchantapi_accounts_v1beta/classes.rb,
lib/google/apis/merchantapi_accounts_v1beta/representations.rb,
lib/google/apis/merchantapi_accounts_v1beta/representations.rb

Overview

Table of per store minimum order values for the pickup fulfillment type.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ MinimumOrderValueTable

Returns a new instance of MinimumOrderValueTable.



2640
2641
2642
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 2640

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#store_code_set_with_movsArray<Google::Apis::MerchantapiAccountsV1beta::StoreCodeSetWithMov>

Required. A list of store code sets sharing the same minimum order value (MOV). At least two sets are required and the last one must be empty, which signifies 'MOV for all other stores'. Each store code can only appear once across all the sets. All prices within a service must have the same currency. Corresponds to the JSON property storeCodeSetWithMovs



2638
2639
2640
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 2638

def store_code_set_with_movs
  @store_code_set_with_movs
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2645
2646
2647
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 2645

def update!(**args)
  @store_code_set_with_movs = args[:store_code_set_with_movs] if args.key?(:store_code_set_with_movs)
end