Class: Google::Apis::MerchantapiAccountsV1beta::OmnichannelSetting
- Inherits:
-
Object
- Object
- Google::Apis::MerchantapiAccountsV1beta::OmnichannelSetting
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/merchantapi_accounts_v1beta/classes.rb,
lib/google/apis/merchantapi_accounts_v1beta/representations.rb,
lib/google/apis/merchantapi_accounts_v1beta/representations.rb
Overview
Collection of information related to the omnichannel settings of a merchant.
Instance Attribute Summary collapse
-
#about ⇒ Google::Apis::MerchantapiAccountsV1beta::About
Collection of information related to the about page (impressum).
-
#in_stock ⇒ Google::Apis::MerchantapiAccountsV1beta::InStock
Collection of information related to InStock.
-
#inventory_verification ⇒ Google::Apis::MerchantapiAccountsV1beta::InventoryVerification
Collection of information related to inventory verification.
-
#lfp_link ⇒ Google::Apis::MerchantapiAccountsV1beta::LfpLink
Collection of information related to the LFP link.
-
#lsf_type ⇒ String
Required.
-
#name ⇒ String
Identifier.
-
#odo ⇒ Google::Apis::MerchantapiAccountsV1beta::OnDisplayToOrder
Collection of information related to the on display to order (ODO).
-
#pickup ⇒ Google::Apis::MerchantapiAccountsV1beta::Pickup
Collection of information related to Pickup.
-
#region_code ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ OmnichannelSetting
constructor
A new instance of OmnichannelSetting.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ OmnichannelSetting
Returns a new instance of OmnichannelSetting.
2707 2708 2709 |
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 2707 def initialize(**args) update!(**args) end |
Instance Attribute Details
#about ⇒ Google::Apis::MerchantapiAccountsV1beta::About
Collection of information related to the about page (impressum).
Corresponds to the JSON property about
2659 2660 2661 |
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 2659 def about @about end |
#in_stock ⇒ Google::Apis::MerchantapiAccountsV1beta::InStock
Collection of information related to InStock.
Corresponds to the JSON property inStock
2664 2665 2666 |
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 2664 def in_stock @in_stock end |
#inventory_verification ⇒ Google::Apis::MerchantapiAccountsV1beta::InventoryVerification
Collection of information related to inventory verification.
Corresponds to the JSON property inventoryVerification
2671 2672 2673 |
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 2671 def inventory_verification @inventory_verification end |
#lfp_link ⇒ Google::Apis::MerchantapiAccountsV1beta::LfpLink
Collection of information related to the LFP link.
Corresponds to the JSON property lfpLink
2676 2677 2678 |
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 2676 def lfp_link @lfp_link end |
#lsf_type ⇒ String
Required. The Local Store Front type for this country.
Corresponds to the JSON property lsfType
2681 2682 2683 |
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 2681 def lsf_type @lsf_type end |
#name ⇒ String
Identifier. The resource name of the omnichannel setting. Format: accounts/
account/omnichannelSettings/omnichannel_setting`
Corresponds to the JSON propertyname`
2687 2688 2689 |
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 2687 def name @name end |
#odo ⇒ Google::Apis::MerchantapiAccountsV1beta::OnDisplayToOrder
Collection of information related to the on display to order (ODO).
Corresponds to the JSON property odo
2694 2695 2696 |
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 2694 def odo @odo end |
#pickup ⇒ Google::Apis::MerchantapiAccountsV1beta::Pickup
Collection of information related to Pickup.
Corresponds to the JSON property pickup
2699 2700 2701 |
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 2699 def pickup @pickup end |
#region_code ⇒ String
Required. Immutable. Region code defined by CLDR.
Must be provided in the Create method, and is immutable.
Corresponds to the JSON property regionCode
2705 2706 2707 |
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 2705 def region_code @region_code end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2712 2713 2714 2715 2716 2717 2718 2719 2720 2721 2722 |
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 2712 def update!(**args) @about = args[:about] if args.key?(:about) @in_stock = args[:in_stock] if args.key?(:in_stock) @inventory_verification = args[:inventory_verification] if args.key?(:inventory_verification) @lfp_link = args[:lfp_link] if args.key?(:lfp_link) @lsf_type = args[:lsf_type] if args.key?(:lsf_type) @name = args[:name] if args.key?(:name) @odo = args[:odo] if args.key?(:odo) @pickup = args[:pickup] if args.key?(:pickup) @region_code = args[:region_code] if args.key?(:region_code) end |