Class: Google::Apis::MerchantapiAccountsV1beta::Program

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/merchantapi_accounts_v1beta/classes.rb,
lib/google/apis/merchantapi_accounts_v1beta/representations.rb,
lib/google/apis/merchantapi_accounts_v1beta/representations.rb

Overview

Defines participation in a given program for the specified account. Programs provide a mechanism for adding functionality to a Merchant Center accounts. A typical example of this is the Free product listings program, which enables products from a business' s store to be shown across Google for free. The following list is the available set of program resource IDs accessible through the API: * checkout

  • free-listings * product-ratings * shopping-ads * youtube-affiliate * youtube-shopping-checkout

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Program

Returns a new instance of Program.



3392
3393
3394
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 3392

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#active_region_codesArray<String>

Output only. The regions in which the account is actively participating in the program. Active regions are defined as those where all program requirements affecting the regions have been met. Region codes are defined by CLDR. This is either a country where the program applies specifically to that country or 001 when the program applies globally. Corresponds to the JSON property activeRegionCodes

Returns:

  • (Array<String>)


3368
3369
3370
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 3368

def active_region_codes
  @active_region_codes
end

#documentation_uriString

Output only. The URL of a Merchant Center help page describing the program. Corresponds to the JSON property documentationUri

Returns:

  • (String)


3373
3374
3375
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 3373

def documentation_uri
  @documentation_uri
end

#nameString

Identifier. The resource name of the program. Format: accounts/account/ programs/program` Corresponds to the JSON propertyname`

Returns:

  • (String)


3379
3380
3381
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 3379

def name
  @name
end

#stateString

Output only. The participation state of the account in the program. Corresponds to the JSON property state

Returns:

  • (String)


3384
3385
3386
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 3384

def state
  @state
end

#unmet_requirementsArray<Google::Apis::MerchantapiAccountsV1beta::Requirement>

Output only. The requirements that the account has not yet satisfied that are affecting participation in the program. Corresponds to the JSON property unmetRequirements



3390
3391
3392
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 3390

def unmet_requirements
  @unmet_requirements
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3397
3398
3399
3400
3401
3402
3403
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 3397

def update!(**args)
  @active_region_codes = args[:active_region_codes] if args.key?(:active_region_codes)
  @documentation_uri = args[:documentation_uri] if args.key?(:documentation_uri)
  @name = args[:name] if args.key?(:name)
  @state = args[:state] if args.key?(:state)
  @unmet_requirements = args[:unmet_requirements] if args.key?(:unmet_requirements)
end