Class: Google::Apis::MerchantapiAccountsV1beta::ProposeAccountServiceRequest
- Inherits:
-
Object
- Object
- Google::Apis::MerchantapiAccountsV1beta::ProposeAccountServiceRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/merchantapi_accounts_v1beta/classes.rb,
lib/google/apis/merchantapi_accounts_v1beta/representations.rb,
lib/google/apis/merchantapi_accounts_v1beta/representations.rb
Overview
Request to propose an account service.
Instance Attribute Summary collapse
-
#account_service ⇒ Google::Apis::MerchantapiAccountsV1beta::AccountService
The
AccountServicemessage represents a specific service that a provider account offers to a Merchant Center account. -
#provider ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ProposeAccountServiceRequest
constructor
A new instance of ProposeAccountServiceRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ProposeAccountServiceRequest
Returns a new instance of ProposeAccountServiceRequest.
3435 3436 3437 |
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 3435 def initialize(**args) update!(**args) end |
Instance Attribute Details
#account_service ⇒ Google::Apis::MerchantapiAccountsV1beta::AccountService
The AccountService message represents a specific service that a provider
account offers to a Merchant Center account. AccountService defines the
permissions and capabilities granted to the provider, allowing for operations
such as product management or campaign management. The lifecycle of an
AccountService involves a proposal phase, where one party suggests the
service, and an approval phase, where the other party accepts or rejects it.
This handshake mechanism ensures mutual consent before any access is granted.
This mechanism safeguards both parties by ensuring that access rights are
granted appropriately and that both the business and provider are aware of the
services enabled. In scenarios where a user is an admin of both accounts, the
approval can happen automatically. The mutability of a service is also managed
through AccountService. Some services might be immutable, for example, if
they were established through other systems or APIs, and you cannot alter them
through this API.
Corresponds to the JSON property accountService
3426 3427 3428 |
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 3426 def account_service @account_service end |
#provider ⇒ String
Required. The provider of the service. Either the reference to an account such
as providers/123 or a well-known service provider (one of providers/
GOOGLE_ADS or providers/GOOGLE_BUSINESS_PROFILE).
Corresponds to the JSON property provider
3433 3434 3435 |
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 3433 def provider @provider end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3440 3441 3442 3443 |
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 3440 def update!(**args) @account_service = args[:account_service] if args.key?(:account_service) @provider = args[:provider] if args.key?(:provider) end |