Class: Google::Apis::MerchantapiAccountsV1beta::RadiusArea
- Inherits:
-
Object
- Object
- Google::Apis::MerchantapiAccountsV1beta::RadiusArea
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/merchantapi_accounts_v1beta/classes.rb,
lib/google/apis/merchantapi_accounts_v1beta/representations.rb,
lib/google/apis/merchantapi_accounts_v1beta/representations.rb
Overview
A radius area that defines the region area.
Instance Attribute Summary collapse
-
#lat_lng ⇒ Google::Apis::MerchantapiAccountsV1beta::LatLng
An object that represents a latitude/longitude pair.
-
#radius ⇒ Float
Required.
-
#radius_units ⇒ String
Optional.
-
#region_code ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RadiusArea
constructor
A new instance of RadiusArea.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RadiusArea
Returns a new instance of RadiusArea.
3474 3475 3476 |
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 3474 def initialize(**args) update!(**args) end |
Instance Attribute Details
#lat_lng ⇒ Google::Apis::MerchantapiAccountsV1beta::LatLng
An object that represents a latitude/longitude pair. This is expressed as a
pair of doubles to represent degrees latitude and degrees longitude. Unless
specified otherwise, this object must conform to the WGS84 standard. Values
must be within normalized ranges.
Corresponds to the JSON property latLng
3456 3457 3458 |
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 3456 def lat_lng @lat_lng end |
#radius ⇒ Float
Required. The radius distance of the area.
Corresponds to the JSON property radius
3461 3462 3463 |
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 3461 def radius @radius end |
#radius_units ⇒ String
Optional. The unit of the radius.
Corresponds to the JSON property radiusUnits
3466 3467 3468 |
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 3466 def radius_units @radius_units end |
#region_code ⇒ String
Required. CLDR territory code or the country the radius area applies to.
Corresponds to the JSON property regionCode
3472 3473 3474 |
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 3472 def region_code @region_code end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3479 3480 3481 3482 3483 3484 |
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 3479 def update!(**args) @lat_lng = args[:lat_lng] if args.key?(:lat_lng) @radius = args[:radius] if args.key?(:radius) @radius_units = args[:radius_units] if args.key?(:radius_units) @region_code = args[:region_code] if args.key?(:region_code) end |