Class: Google::Apis::MerchantapiAccountsV1beta::RequestInventoryVerificationResponse
- Inherits:
-
Object
- Object
- Google::Apis::MerchantapiAccountsV1beta::RequestInventoryVerificationResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/merchantapi_accounts_v1beta/classes.rb,
lib/google/apis/merchantapi_accounts_v1beta/representations.rb,
lib/google/apis/merchantapi_accounts_v1beta/representations.rb
Overview
Response message for the RequestInventoryVerification method.
Instance Attribute Summary collapse
-
#omnichannel_setting ⇒ Google::Apis::MerchantapiAccountsV1beta::OmnichannelSetting
Collection of information related to the omnichannel settings of a merchant.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RequestInventoryVerificationResponse
constructor
A new instance of RequestInventoryVerificationResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RequestInventoryVerificationResponse
Returns a new instance of RequestInventoryVerificationResponse.
3676 3677 3678 |
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 3676 def initialize(**args) update!(**args) end |
Instance Attribute Details
#omnichannel_setting ⇒ Google::Apis::MerchantapiAccountsV1beta::OmnichannelSetting
Collection of information related to the omnichannel settings of a merchant.
Corresponds to the JSON property omnichannelSetting
3674 3675 3676 |
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 3674 def omnichannel_setting @omnichannel_setting end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3681 3682 3683 |
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 3681 def update!(**args) @omnichannel_setting = args[:omnichannel_setting] if args.key?(:omnichannel_setting) end |