Class: Google::Apis::MerchantapiAccountsV1beta::SeasonalOverride
- Inherits:
-
Object
- Object
- Google::Apis::MerchantapiAccountsV1beta::SeasonalOverride
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/merchantapi_accounts_v1beta/classes.rb,
lib/google/apis/merchantapi_accounts_v1beta/representations.rb,
lib/google/apis/merchantapi_accounts_v1beta/representations.rb
Instance Attribute Summary collapse
-
#end_date ⇒ Google::Apis::MerchantapiAccountsV1beta::Date
Represents a whole or partial calendar date, such as a birthday.
-
#label ⇒ String
Required.
-
#return_days ⇒ Fixnum
Number of days (from the delivery date) that the product can be returned.
-
#return_until_date ⇒ Google::Apis::MerchantapiAccountsV1beta::Date
Represents a whole or partial calendar date, such as a birthday.
-
#start_date ⇒ Google::Apis::MerchantapiAccountsV1beta::Date
Represents a whole or partial calendar date, such as a birthday.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SeasonalOverride
constructor
A new instance of SeasonalOverride.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SeasonalOverride
Returns a new instance of SeasonalOverride.
3869 3870 3871 |
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 3869 def initialize(**args) update!(**args) end |
Instance Attribute Details
#end_date ⇒ Google::Apis::MerchantapiAccountsV1beta::Date
Represents a whole or partial calendar date, such as a birthday. The time of
day and time zone are either specified elsewhere or are insignificant. The
date is relative to the Gregorian Calendar. This can represent one of the
following: * A full date, with non-zero year, month, and day values. * A month
and day, with a zero year (for example, an anniversary). * A year on its own,
with a zero month and a zero day. * A year and month, with a zero day (for
example, a credit card expiration date). Related types: * google.type.
TimeOfDay * google.type.DateTime * google.protobuf.Timestamp
Corresponds to the JSON property endDate
3833 3834 3835 |
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 3833 def end_date @end_date end |
#label ⇒ String
Required. Display name of this seasonal override in Merchant Center.
Corresponds to the JSON property label
3838 3839 3840 |
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 3838 def label @label end |
#return_days ⇒ Fixnum
Number of days (from the delivery date) that the product can be returned.
Corresponds to the JSON property returnDays
3843 3844 3845 |
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 3843 def return_days @return_days end |
#return_until_date ⇒ Google::Apis::MerchantapiAccountsV1beta::Date
Represents a whole or partial calendar date, such as a birthday. The time of
day and time zone are either specified elsewhere or are insignificant. The
date is relative to the Gregorian Calendar. This can represent one of the
following: * A full date, with non-zero year, month, and day values. * A month
and day, with a zero year (for example, an anniversary). * A year on its own,
with a zero month and a zero day. * A year and month, with a zero day (for
example, a credit card expiration date). Related types: * google.type.
TimeOfDay * google.type.DateTime * google.protobuf.Timestamp
Corresponds to the JSON property returnUntilDate
3855 3856 3857 |
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 3855 def return_until_date @return_until_date end |
#start_date ⇒ Google::Apis::MerchantapiAccountsV1beta::Date
Represents a whole or partial calendar date, such as a birthday. The time of
day and time zone are either specified elsewhere or are insignificant. The
date is relative to the Gregorian Calendar. This can represent one of the
following: * A full date, with non-zero year, month, and day values. * A month
and day, with a zero year (for example, an anniversary). * A year on its own,
with a zero month and a zero day. * A year and month, with a zero day (for
example, a credit card expiration date). Related types: * google.type.
TimeOfDay * google.type.DateTime * google.protobuf.Timestamp
Corresponds to the JSON property startDate
3867 3868 3869 |
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 3867 def start_date @start_date end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3874 3875 3876 3877 3878 3879 3880 |
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 3874 def update!(**args) @end_date = args[:end_date] if args.key?(:end_date) @label = args[:label] if args.key?(:label) @return_days = args[:return_days] if args.key?(:return_days) @return_until_date = args[:return_until_date] if args.key?(:return_until_date) @start_date = args[:start_date] if args.key?(:start_date) end |