Class: Google::Apis::MerchantapiAccountsV1beta::SetAliasForRelationship
- Inherits:
-
Object
- Object
- Google::Apis::MerchantapiAccountsV1beta::SetAliasForRelationship
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/merchantapi_accounts_v1beta/classes.rb,
lib/google/apis/merchantapi_accounts_v1beta/representations.rb,
lib/google/apis/merchantapi_accounts_v1beta/representations.rb
Overview
Set an alias for a relationship between a provider and the account to be created.
Instance Attribute Summary collapse
-
#account_id_alias ⇒ String
Required.
-
#provider ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SetAliasForRelationship
constructor
A new instance of SetAliasForRelationship.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SetAliasForRelationship
Returns a new instance of SetAliasForRelationship.
3992 3993 3994 |
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 3992 def initialize(**args) update!(**args) end |
Instance Attribute Details
#account_id_alias ⇒ String
Required. The unique ID of this account in the provider's system. The value
must be unique across all accounts on the platform for this provider.
Corresponds to the JSON property accountIdAlias
3983 3984 3985 |
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 3983 def account_id_alias @account_id_alias end |
#provider ⇒ String
Required. The provider of the service. This is a reference to an account such
as providers/123 or accounts/123. The same provider must be specified in
at least one of the service fields.
Corresponds to the JSON property provider
3990 3991 3992 |
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 3990 def provider @provider end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3997 3998 3999 4000 |
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 3997 def update!(**args) @account_id_alias = args[:account_id_alias] if args.key?(:account_id_alias) @provider = args[:provider] if args.key?(:provider) end |