Class: Google::Apis::MerchantapiAccountsV1beta::SetAliasForRelationship

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/merchantapi_accounts_v1beta/classes.rb,
lib/google/apis/merchantapi_accounts_v1beta/representations.rb,
lib/google/apis/merchantapi_accounts_v1beta/representations.rb

Overview

Set an alias for a relationship between a provider and the account to be created.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SetAliasForRelationship

Returns a new instance of SetAliasForRelationship.



3986
3987
3988
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 3986

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#account_id_aliasString

Required. The unique ID of this account in the provider's system. The value must be unique across all accounts on the platform for this provider. Corresponds to the JSON property accountIdAlias

Returns:

  • (String)


3977
3978
3979
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 3977

def 
  @account_id_alias
end

#providerString

Required. The provider of the service. This is a reference to an account such as providers/123 or accounts/123. The same provider must be specified in at least one of the service fields. Corresponds to the JSON property provider

Returns:

  • (String)


3984
3985
3986
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 3984

def provider
  @provider
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3991
3992
3993
3994
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 3991

def update!(**args)
  @account_id_alias = args[:account_id_alias] if args.key?(:account_id_alias)
  @provider = args[:provider] if args.key?(:provider)
end