Class: Google::Apis::MerchantapiAccountsV1beta::ShortCode
- Inherits:
-
Object
- Object
- Google::Apis::MerchantapiAccountsV1beta::ShortCode
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/merchantapi_accounts_v1beta/classes.rb,
lib/google/apis/merchantapi_accounts_v1beta/representations.rb,
lib/google/apis/merchantapi_accounts_v1beta/representations.rb
Overview
An object representing a short code, which is a phone number that is typically much shorter than regular phone numbers and can be used to address messages in MMS and SMS systems, as well as for abbreviated dialing (For example "Text 611 to see how many minutes you have remaining on your plan."). Short codes are restricted to a region and are not internationally dialable, which means the same short code can exist in different regions, with different usage and pricing, even if those regions share the same country calling code (For example: US and CA).
Instance Attribute Summary collapse
-
#number ⇒ String
Required.
-
#region_code ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ShortCode
constructor
A new instance of ShortCode.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ShortCode
Returns a new instance of ShortCode.
4072 4073 4074 |
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 4072 def initialize(**args) update!(**args) end |
Instance Attribute Details
#number ⇒ String
Required. The short code digits, without a leading plus ('+') or country
calling code. For example "611".
Corresponds to the JSON property number
4063 4064 4065 |
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 4063 def number @number end |
#region_code ⇒ String
Required. The BCP-47 region code of the location where calls to this short
code can be made, such as "US" and "BB". Reference(s): - http://www.unicode.
org/reports/tr35/#unicode_region_subtag
Corresponds to the JSON property regionCode
4070 4071 4072 |
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 4070 def region_code @region_code end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4077 4078 4079 4080 |
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 4077 def update!(**args) @number = args[:number] if args.key?(:number) @region_code = args[:region_code] if args.key?(:region_code) end |