Class: Google::Apis::MerchantapiAccountsV1beta::StoreCodeSetWithMov
- Inherits:
-
Object
- Object
- Google::Apis::MerchantapiAccountsV1beta::StoreCodeSetWithMov
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/merchantapi_accounts_v1beta/classes.rb,
lib/google/apis/merchantapi_accounts_v1beta/representations.rb,
lib/google/apis/merchantapi_accounts_v1beta/representations.rb
Overview
A list of store code sets sharing the same minimum order value. At least two sets are required and the last one must be empty, which signifies 'MOV for all other stores'. Each store code can only appear once across all the sets. All prices within a service must have the same currency.
Instance Attribute Summary collapse
-
#store_codes ⇒ Array<String>
Optional.
-
#value ⇒ Google::Apis::MerchantapiAccountsV1beta::Price
The price represented as a number and currency.
Instance Method Summary collapse
-
#initialize(**args) ⇒ StoreCodeSetWithMov
constructor
A new instance of StoreCodeSetWithMov.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ StoreCodeSetWithMov
Returns a new instance of StoreCodeSetWithMov.
4100 4101 4102 |
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 4100 def initialize(**args) update!(**args) end |
Instance Attribute Details
#store_codes ⇒ Array<String>
Optional. A list of unique store codes or empty for the catch all.
Corresponds to the JSON property storeCodes
4093 4094 4095 |
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 4093 def store_codes @store_codes end |
#value ⇒ Google::Apis::MerchantapiAccountsV1beta::Price
The price represented as a number and currency.
Corresponds to the JSON property value
4098 4099 4100 |
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 4098 def value @value end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4105 4106 4107 4108 |
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 4105 def update!(**args) @store_codes = args[:store_codes] if args.key?(:store_codes) @value = args[:value] if args.key?(:value) end |