Class: Google::Apis::MerchantapiAccountsV1beta::StoreConfig
- Inherits:
-
Object
- Object
- Google::Apis::MerchantapiAccountsV1beta::StoreConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/merchantapi_accounts_v1beta/classes.rb,
lib/google/apis/merchantapi_accounts_v1beta/representations.rb,
lib/google/apis/merchantapi_accounts_v1beta/representations.rb
Overview
A list of stores your products are delivered from. This is only valid for the local delivery shipment type.
Instance Attribute Summary collapse
-
#cutoff_config ⇒ Google::Apis::MerchantapiAccountsV1beta::CutoffConfig
Configs related to local delivery ends for the day.
-
#service_radius ⇒ Google::Apis::MerchantapiAccountsV1beta::Distance
Maximum delivery radius.
-
#store_codes ⇒ Array<String>
Optional.
-
#store_service_type ⇒ String
Indicates whether all stores, or selected stores, listed by this business provide local delivery.
Instance Method Summary collapse
-
#initialize(**args) ⇒ StoreConfig
constructor
A new instance of StoreConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ StoreConfig
Returns a new instance of StoreConfig.
4139 4140 4141 |
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 4139 def initialize(**args) update!(**args) end |
Instance Attribute Details
#cutoff_config ⇒ Google::Apis::MerchantapiAccountsV1beta::CutoffConfig
Configs related to local delivery ends for the day.
Corresponds to the JSON property cutoffConfig
4119 4120 4121 |
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 4119 def cutoff_config @cutoff_config end |
#service_radius ⇒ Google::Apis::MerchantapiAccountsV1beta::Distance
Maximum delivery radius. This is only required for the local delivery shipment
type.
Corresponds to the JSON property serviceRadius
4125 4126 4127 |
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 4125 def service_radius @service_radius end |
#store_codes ⇒ Array<String>
Optional. A list of store codes that provide local delivery. If empty, then
all_stores must be true.
Corresponds to the JSON property storeCodes
4131 4132 4133 |
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 4131 def store_codes @store_codes end |
#store_service_type ⇒ String
Indicates whether all stores, or selected stores, listed by this business
provide local delivery.
Corresponds to the JSON property storeServiceType
4137 4138 4139 |
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 4137 def store_service_type @store_service_type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4144 4145 4146 4147 4148 4149 |
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 4144 def update!(**args) @cutoff_config = args[:cutoff_config] if args.key?(:cutoff_config) @service_radius = args[:service_radius] if args.key?(:service_radius) @store_codes = args[:store_codes] if args.key?(:store_codes) @store_service_type = args[:store_service_type] if args.key?(:store_service_type) end |