Class: Google::Apis::MerchantapiAccountsV1beta::TermsOfService
- Inherits:
-
Object
- Object
- Google::Apis::MerchantapiAccountsV1beta::TermsOfService
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/merchantapi_accounts_v1beta/classes.rb,
lib/google/apis/merchantapi_accounts_v1beta/representations.rb,
lib/google/apis/merchantapi_accounts_v1beta/representations.rb
Overview
The TermsOfService message represents a specific version of the terms of
service that merchants must accept to access certain features or services. For
more information, see Terms of Service. This message is important for the onboarding process, ensuring
that merchants agree to the necessary legal agreements for using the service.
Merchants can retrieve the latest terms of service for a given kind and
region through RetrieveLatestTermsOfService, and accept them as required
through AcceptTermsOfService.
Instance Attribute Summary collapse
-
#external ⇒ Boolean
(also: #external?)
Whether this terms of service version is external.
-
#file_uri ⇒ String
URI for terms of service file that needs to be displayed to signing users.
-
#kind ⇒ String
The Kind this terms of service version applies to.
-
#name ⇒ String
Identifier.
-
#region_code ⇒ String
Region code as defined by CLDR.
Instance Method Summary collapse
-
#initialize(**args) ⇒ TermsOfService
constructor
A new instance of TermsOfService.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ TermsOfService
Returns a new instance of TermsOfService.
4237 4238 4239 |
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 4237 def initialize(**args) update!(**args) end |
Instance Attribute Details
#external ⇒ Boolean Also known as: external?
Whether this terms of service version is external. External terms of service
versions can only be agreed through external processes and not directly by the
merchant through UI or API.
Corresponds to the JSON property external
4208 4209 4210 |
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 4208 def external @external end |
#file_uri ⇒ String
URI for terms of service file that needs to be displayed to signing users.
Corresponds to the JSON property fileUri
4214 4215 4216 |
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 4214 def file_uri @file_uri end |
#kind ⇒ String
The Kind this terms of service version applies to.
Corresponds to the JSON property kind
4219 4220 4221 |
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 4219 def kind @kind end |
#name ⇒ String
Identifier. The resource name of the terms of service version. Format:
termsOfService/version`
Corresponds to the JSON propertyname`
4225 4226 4227 |
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 4225 def name @name end |
#region_code ⇒ String
Region code as defined by CLDR. This is either a
country where the ToS applies specifically to that country or 001 when the
same TermsOfService can be signed in any country. However note that when
signing a ToS that applies globally we still expect that a specific country is
provided (this should be merchant business country or program country of
participation).
Corresponds to the JSON property regionCode
4235 4236 4237 |
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 4235 def region_code @region_code end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4242 4243 4244 4245 4246 4247 4248 |
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 4242 def update!(**args) @external = args[:external] if args.key?(:external) @file_uri = args[:file_uri] if args.key?(:file_uri) @kind = args[:kind] if args.key?(:kind) @name = args[:name] if args.key?(:name) @region_code = args[:region_code] if args.key?(:region_code) end |