Class: Google::Apis::MerchantapiAccountsV1beta::TermsOfServiceAgreementState
- Inherits:
-
Object
- Object
- Google::Apis::MerchantapiAccountsV1beta::TermsOfServiceAgreementState
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/merchantapi_accounts_v1beta/classes.rb,
lib/google/apis/merchantapi_accounts_v1beta/representations.rb,
lib/google/apis/merchantapi_accounts_v1beta/representations.rb
Overview
This resource represents the agreement state for a given account and terms of
service kind. The state is as follows: * If the business has accepted a terms
of service, accepted will be populated, otherwise it will be empty * If the
business must sign a terms of service, required will be populated, otherwise
it will be empty. Note that both required and accepted can be present. In
this case the accepted terms of services will have an expiration date set in
the valid_until field. The required terms of services need to be accepted
before valid_until in order for the account to continue having a valid
agreement. When accepting new terms of services we expect third-party
providers to display the text associated with the given terms of service
agreement (the url to the file containing the text is added in the Required
message below as tos_file_uri). The actual acceptance of the terms of
service is done by calling accept on the TermsOfService resource.
valid_until field.
Instance Attribute Summary collapse
-
#accepted ⇒ Google::Apis::MerchantapiAccountsV1beta::Accepted
Describes the accepted terms of service.
-
#name ⇒ String
Identifier.
-
#region_code ⇒ String
Required.
-
#required ⇒ Google::Apis::MerchantapiAccountsV1beta::Required
Describes the terms of service which are required to be accepted.
-
#terms_of_service_kind ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ TermsOfServiceAgreementState
constructor
A new instance of TermsOfServiceAgreementState.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ TermsOfServiceAgreementState
Returns a new instance of TermsOfServiceAgreementState.
4299 4300 4301 |
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 4299 def initialize(**args) update!(**args) end |
Instance Attribute Details
#accepted ⇒ Google::Apis::MerchantapiAccountsV1beta::Accepted
Describes the accepted terms of service.
Corresponds to the JSON property accepted
4273 4274 4275 |
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 4273 def accepted @accepted end |
#name ⇒ String
Identifier. The resource name of the terms of service version. Format:
accounts/account/termsOfServiceAgreementState/identifierThe identifier
format is:TermsOfServiceKind-country`For example, an identifier could
be:MERCHANT_CENTER-EUorMERCHANT_CENTER-US.
Corresponds to the JSON propertyname`
4281 4282 4283 |
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 4281 def name @name end |
#region_code ⇒ String
Required. Region code as defined by https://cldr.unicode.org/. This is the
country the current state applies to.
Corresponds to the JSON property regionCode
4287 4288 4289 |
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 4287 def region_code @region_code end |
#required ⇒ Google::Apis::MerchantapiAccountsV1beta::Required
Describes the terms of service which are required to be accepted.
Corresponds to the JSON property required
4292 4293 4294 |
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 4292 def required @required end |
#terms_of_service_kind ⇒ String
Required. Terms of Service kind associated with the particular version.
Corresponds to the JSON property termsOfServiceKind
4297 4298 4299 |
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 4297 def terms_of_service_kind @terms_of_service_kind end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4304 4305 4306 4307 4308 4309 4310 |
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 4304 def update!(**args) @accepted = args[:accepted] if args.key?(:accepted) @name = args[:name] if args.key?(:name) @region_code = args[:region_code] if args.key?(:region_code) @required = args[:required] if args.key?(:required) @terms_of_service_kind = args[:terms_of_service_kind] if args.key?(:terms_of_service_kind) end |