Class: Google::Apis::MerchantapiAccountsV1beta::UriSettings
- Inherits:
-
Object
- Object
- Google::Apis::MerchantapiAccountsV1beta::UriSettings
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/merchantapi_accounts_v1beta/classes.rb,
lib/google/apis/merchantapi_accounts_v1beta/representations.rb,
lib/google/apis/merchantapi_accounts_v1beta/representations.rb
Overview
URL settings for cart or checkout URL.
Instance Attribute Summary collapse
-
#cart_uri_template ⇒ String
Cart URL template.
-
#checkout_uri_template ⇒ String
Checkout URL template.
Instance Method Summary collapse
-
#initialize(**args) ⇒ UriSettings
constructor
A new instance of UriSettings.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ UriSettings
Returns a new instance of UriSettings.
4493 4494 4495 |
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 4493 def initialize(**args) update!(**args) end |
Instance Attribute Details
#cart_uri_template ⇒ String
Cart URL template. When the placeholders are expanded will redirect the buyer
to the cart page on the merchant website with the selected item in cart. For
more details, check the help center doc
Corresponds to the JSON property cartUriTemplate
4482 4483 4484 |
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 4482 def cart_uri_template @cart_uri_template end |
#checkout_uri_template ⇒ String
Checkout URL template. When the placeholders are expanded will redirect the
buyer to the merchant checkout page with the item in the cart. For more
details, check the help center doc
Corresponds to the JSON property checkoutUriTemplate
4491 4492 4493 |
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 4491 def checkout_uri_template @checkout_uri_template end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4498 4499 4500 4501 |
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 4498 def update!(**args) @cart_uri_template = args[:cart_uri_template] if args.key?(:cart_uri_template) @checkout_uri_template = args[:checkout_uri_template] if args.key?(:checkout_uri_template) end |