Class: Google::Apis::MerchantapiAccountsV1beta::UriSettings
- Inherits:
-
Object
- Object
- Google::Apis::MerchantapiAccountsV1beta::UriSettings
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/merchantapi_accounts_v1beta/classes.rb,
lib/google/apis/merchantapi_accounts_v1beta/representations.rb,
lib/google/apis/merchantapi_accounts_v1beta/representations.rb
Overview
URL settings for cart or checkout URL.
Instance Attribute Summary collapse
-
#cart_uri_template ⇒ String
Cart URL template.
-
#checkout_uri_template ⇒ String
Checkout URL template.
Instance Method Summary collapse
-
#initialize(**args) ⇒ UriSettings
constructor
A new instance of UriSettings.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ UriSettings
Returns a new instance of UriSettings.
4474 4475 4476 |
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 4474 def initialize(**args) update!(**args) end |
Instance Attribute Details
#cart_uri_template ⇒ String
Cart URL template. When the placeholders are expanded will redirect the buyer
to the cart page on the merchant website with the selected item in cart. For
more details, check the help center doc
Corresponds to the JSON property cartUriTemplate
4463 4464 4465 |
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 4463 def cart_uri_template @cart_uri_template end |
#checkout_uri_template ⇒ String
Checkout URL template. When the placeholders are expanded will redirect the
buyer to the merchant checkout page with the item in the cart. For more
details, check the help center doc
Corresponds to the JSON property checkoutUriTemplate
4472 4473 4474 |
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 4472 def checkout_uri_template @checkout_uri_template end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4479 4480 4481 4482 |
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 4479 def update!(**args) @cart_uri_template = args[:cart_uri_template] if args.key?(:cart_uri_template) @checkout_uri_template = args[:checkout_uri_template] if args.key?(:checkout_uri_template) end |