Class: Google::Apis::MerchantapiAccountsV1beta::User
- Inherits:
-
Object
- Object
- Google::Apis::MerchantapiAccountsV1beta::User
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/merchantapi_accounts_v1beta/classes.rb,
lib/google/apis/merchantapi_accounts_v1beta/representations.rb,
lib/google/apis/merchantapi_accounts_v1beta/representations.rb
Overview
The User resource represents a user associated with a Merchant Center
account. It is used to manage user permissions and access rights within the
account. For more information, see Frequently asked questions about people
and access levels.
Instance Attribute Summary collapse
-
#access_rights ⇒ Array<String>
Required.
-
#name ⇒ String
Identifier.
-
#state ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ User
constructor
A new instance of User.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ User
Returns a new instance of User.
4510 4511 4512 |
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 4510 def initialize(**args) update!(**args) end |
Instance Attribute Details
#access_rights ⇒ Array<String>
Required. The access rights the user has.
Corresponds to the JSON property accessRights
4496 4497 4498 |
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 4496 def access_rights @access_rights end |
#name ⇒ String
Identifier. The resource name of the user. Format: accounts/account/user/
email`Usemeto refer to your own email address, for exampleaccounts/
account/users/me.
Corresponds to the JSON propertyname`
4503 4504 4505 |
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 4503 def name @name end |
#state ⇒ String
Output only. The state of the user.
Corresponds to the JSON property state
4508 4509 4510 |
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 4508 def state @state end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4515 4516 4517 4518 4519 |
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 4515 def update!(**args) @access_rights = args[:access_rights] if args.key?(:access_rights) @name = args[:name] if args.key?(:name) @state = args[:state] if args.key?(:state) end |