Class: Google::Apis::MerchantapiAccountsV1beta::Warehouse
- Inherits:
-
Object
- Object
- Google::Apis::MerchantapiAccountsV1beta::Warehouse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/merchantapi_accounts_v1beta/classes.rb,
lib/google/apis/merchantapi_accounts_v1beta/representations.rb,
lib/google/apis/merchantapi_accounts_v1beta/representations.rb
Overview
A fulfillment warehouse, which stores and handles inventory.
Instance Attribute Summary collapse
-
#business_day_config ⇒ Google::Apis::MerchantapiAccountsV1beta::BusinessDayConfig
Business days of the warehouse.
-
#cutoff_time ⇒ Google::Apis::MerchantapiAccountsV1beta::WarehouseCutoffTime
The latest time of day that an order can be accepted and begin processing.
-
#handling_days ⇒ Fixnum
Required.
-
#name ⇒ String
Required.
-
#shipping_address ⇒ Google::Apis::MerchantapiAccountsV1beta::Address
Shipping address of the warehouse.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Warehouse
constructor
A new instance of Warehouse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Warehouse
Returns a new instance of Warehouse.
4638 4639 4640 |
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 4638 def initialize(**args) update!(**args) end |
Instance Attribute Details
#business_day_config ⇒ Google::Apis::MerchantapiAccountsV1beta::BusinessDayConfig
Business days of the warehouse.
Corresponds to the JSON property businessDayConfig
4612 4613 4614 |
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 4612 def business_day_config @business_day_config end |
#cutoff_time ⇒ Google::Apis::MerchantapiAccountsV1beta::WarehouseCutoffTime
The latest time of day that an order can be accepted and begin processing.
Later orders will be processed in the next day. The time is based on the
warehouse postal code.
Corresponds to the JSON property cutoffTime
4619 4620 4621 |
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 4619 def cutoff_time @cutoff_time end |
#handling_days ⇒ Fixnum
Required. The number of days it takes for this warehouse to pack up and ship
an item. This is on the warehouse level, but can be overridden on the offer
level based on the attributes of an item.
Corresponds to the JSON property handlingDays
4626 4627 4628 |
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 4626 def handling_days @handling_days end |
#name ⇒ String
Required. The name of the warehouse. Must be unique within account.
Corresponds to the JSON property name
4631 4632 4633 |
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 4631 def name @name end |
#shipping_address ⇒ Google::Apis::MerchantapiAccountsV1beta::Address
Shipping address of the warehouse.
Corresponds to the JSON property shippingAddress
4636 4637 4638 |
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 4636 def shipping_address @shipping_address end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4643 4644 4645 4646 4647 4648 4649 |
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 4643 def update!(**args) @business_day_config = args[:business_day_config] if args.key?(:business_day_config) @cutoff_time = args[:cutoff_time] if args.key?(:cutoff_time) @handling_days = args[:handling_days] if args.key?(:handling_days) @name = args[:name] if args.key?(:name) @shipping_address = args[:shipping_address] if args.key?(:shipping_address) end |