Class: Google::Apis::MerchantapiAccountsV1beta::WarehouseBasedDeliveryTime

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/merchantapi_accounts_v1beta/classes.rb,
lib/google/apis/merchantapi_accounts_v1beta/representations.rb,
lib/google/apis/merchantapi_accounts_v1beta/representations.rb

Overview

Indicates that the delivery time should be calculated per warehouse (shipping origin location) based on the settings of the selected carrier. When set, no other transit time related field in delivery_time should be set.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ WarehouseBasedDeliveryTime

Returns a new instance of WarehouseBasedDeliveryTime.



4676
4677
4678
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 4676

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#carrierString

Required. Carrier, such as "UPS" or "Fedex". supported carriers Corresponds to the JSON property carrier

Returns:

  • (String)


4663
4664
4665
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 4663

def carrier
  @carrier
end

#carrier_serviceString

Required. Carrier service, such as "ground" or "2 days". The name of the service must be in the eddSupportedServices list. Corresponds to the JSON property carrierService

Returns:

  • (String)


4669
4670
4671
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 4669

def carrier_service
  @carrier_service
end

#warehouseString

Required. Warehouse name. This should match warehouse. Corresponds to the JSON property warehouse

Returns:

  • (String)


4674
4675
4676
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 4674

def warehouse
  @warehouse
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4681
4682
4683
4684
4685
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 4681

def update!(**args)
  @carrier = args[:carrier] if args.key?(:carrier)
  @carrier_service = args[:carrier_service] if args.key?(:carrier_service)
  @warehouse = args[:warehouse] if args.key?(:warehouse)
end