Class: Google::Apis::MerchantapiAccountsV1beta::WarehouseCutoffTime
- Inherits:
-
Object
- Object
- Google::Apis::MerchantapiAccountsV1beta::WarehouseCutoffTime
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/merchantapi_accounts_v1beta/classes.rb,
lib/google/apis/merchantapi_accounts_v1beta/representations.rb,
lib/google/apis/merchantapi_accounts_v1beta/representations.rb
Overview
The latest time of day that an order can be accepted and begin processing. Later orders will be processed in the next day. The time is based on the warehouse postal code.
Instance Attribute Summary collapse
-
#hour ⇒ Fixnum
Required.
-
#minute ⇒ Fixnum
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ WarehouseCutoffTime
constructor
A new instance of WarehouseCutoffTime.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ WarehouseCutoffTime
Returns a new instance of WarehouseCutoffTime.
4708 4709 4710 |
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 4708 def initialize(**args) update!(**args) end |
Instance Attribute Details
#hour ⇒ Fixnum
Required. Hour of the cutoff time until which an order has to be placed to be
processed in the same day by the warehouse. Hour is based on the timezone of
warehouse.
Corresponds to the JSON property hour
4699 4700 4701 |
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 4699 def hour @hour end |
#minute ⇒ Fixnum
Required. Minute of the cutoff time until which an order has to be placed to
be processed in the same day by the warehouse. Minute is based on the timezone
of warehouse.
Corresponds to the JSON property minute
4706 4707 4708 |
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 4706 def minute @minute end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4713 4714 4715 4716 |
# File 'lib/google/apis/merchantapi_accounts_v1beta/classes.rb', line 4713 def update!(**args) @hour = args[:hour] if args.key?(:hour) @minute = args[:minute] if args.key?(:minute) end |